# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/domo_library',
                'doc_host': 'https://jaewilson07.github.io',
                'git_url': 'https://github.com/jaewilson07/domo_library',
                'lib_path': 'domolibrary'},
  'syms': { 'domolibrary.classes.DomoAccount': { 'domolibrary.classes.DomoAccount.AccountConfig': ( 'classes/domoaccount.html#accountconfig',
                                                                                                    'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount': ( 'classes/domoaccount.html#domoaccount',
                                                                                                  'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount._from_json': ( 'classes/domoaccount.html#domoaccount._from_json',
                                                                                                             'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount._get_config': ( 'classes/domoaccount.html#domoaccount._get_config',
                                                                                                              'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount._is_group_ownership_beta': ( 'classes/domoaccount.html#domoaccount._is_group_ownership_beta',
                                                                                                                           'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount.create_account': ( 'classes/domoaccount.html#domoaccount.create_account',
                                                                                                                 'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount.delete_account': ( 'classes/domoaccount.html#domoaccount.delete_account',
                                                                                                                 'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount.generate_create_body': ( 'classes/domoaccount.html#domoaccount.generate_create_body',
                                                                                                                       'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount.get_from_id': ( 'classes/domoaccount.html#domoaccount.get_from_id',
                                                                                                              'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount.share': ( 'classes/domoaccount.html#domoaccount.share',
                                                                                                        'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount.share_account': ( 'classes/domoaccount.html#domoaccount.share_account',
                                                                                                                'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount.update_config': ( 'classes/domoaccount.html#domoaccount.update_config',
                                                                                                                'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount.update_name': ( 'classes/domoaccount.html#domoaccount.update_name',
                                                                                                              'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount_Config': ( 'classes/domoaccount.html#domoaccount_config',
                                                                                                         'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount_Config._from_json': ( 'classes/domoaccount.html#domoaccount_config._from_json',
                                                                                                                    'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount_Config.to_json': ( 'classes/domoaccount.html#domoaccount_config.to_json',
                                                                                                                 'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount_Config_AbstractCredential': ( 'classes/domoaccount.html#domoaccount_config_abstractcredential',
                                                                                                                            'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount_Config_AbstractCredential._from_json': ( 'classes/domoaccount.html#domoaccount_config_abstractcredential._from_json',
                                                                                                                                       'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount_Config_AbstractCredential.to_json': ( 'classes/domoaccount.html#domoaccount_config_abstractcredential.to_json',
                                                                                                                                    'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount_Config_AmazonS3': ( 'classes/domoaccount.html#domoaccount_config_amazons3',
                                                                                                                  'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount_Config_AmazonS3._from_json': ( 'classes/domoaccount.html#domoaccount_config_amazons3._from_json',
                                                                                                                             'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount_Config_AmazonS3.to_json': ( 'classes/domoaccount.html#domoaccount_config_amazons3.to_json',
                                                                                                                          'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount_Config_AmazonS3Advanced': ( 'classes/domoaccount.html#domoaccount_config_amazons3advanced',
                                                                                                                          'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount_Config_AmazonS3Advanced._from_json': ( 'classes/domoaccount.html#domoaccount_config_amazons3advanced._from_json',
                                                                                                                                     'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount_Config_AmazonS3Advanced.to_json': ( 'classes/domoaccount.html#domoaccount_config_amazons3advanced.to_json',
                                                                                                                                  'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount_Config_AwsAthena': ( 'classes/domoaccount.html#domoaccount_config_awsathena',
                                                                                                                   'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount_Config_AwsAthena._from_json': ( 'classes/domoaccount.html#domoaccount_config_awsathena._from_json',
                                                                                                                              'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount_Config_AwsAthena.to_json': ( 'classes/domoaccount.html#domoaccount_config_awsathena.to_json',
                                                                                                                           'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount_Config_DatasetCopy': ( 'classes/domoaccount.html#domoaccount_config_datasetcopy',
                                                                                                                     'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount_Config_DatasetCopy._from_json': ( 'classes/domoaccount.html#domoaccount_config_datasetcopy._from_json',
                                                                                                                                'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount_Config_DatasetCopy.to_json': ( 'classes/domoaccount.html#domoaccount_config_datasetcopy.to_json',
                                                                                                                             'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount_Config_DomoAccessToken': ( 'classes/domoaccount.html#domoaccount_config_domoaccesstoken',
                                                                                                                         'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount_Config_DomoAccessToken._from_json': ( 'classes/domoaccount.html#domoaccount_config_domoaccesstoken._from_json',
                                                                                                                                    'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount_Config_DomoAccessToken.to_json': ( 'classes/domoaccount.html#domoaccount_config_domoaccesstoken.to_json',
                                                                                                                                 'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount_Config_Governance': ( 'classes/domoaccount.html#domoaccount_config_governance',
                                                                                                                    'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount_Config_Governance._from_json': ( 'classes/domoaccount.html#domoaccount_config_governance._from_json',
                                                                                                                               'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount_Config_Governance.to_json': ( 'classes/domoaccount.html#domoaccount_config_governance.to_json',
                                                                                                                            'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount_Config_HighBandwidthConnector': ( 'classes/domoaccount.html#domoaccount_config_highbandwidthconnector',
                                                                                                                                'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount_Config_HighBandwidthConnector._from_json': ( 'classes/domoaccount.html#domoaccount_config_highbandwidthconnector._from_json',
                                                                                                                                           'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount_Config_HighBandwidthConnector.to_json': ( 'classes/domoaccount.html#domoaccount_config_highbandwidthconnector.to_json',
                                                                                                                                        'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount_CreateAccount_Error': ( 'classes/domoaccount.html#domoaccount_createaccount_error',
                                                                                                                      'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount_CreateAccount_Error.__init__': ( 'classes/domoaccount.html#domoaccount_createaccount_error.__init__',
                                                                                                                               'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount_DataProviderType_ConfigNotDefined': ( 'classes/domoaccount.html#domoaccount_dataprovidertype_confignotdefined',
                                                                                                                                    'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount_DataProviderType_ConfigNotDefined.__init__': ( 'classes/domoaccount.html#domoaccount_dataprovidertype_confignotdefined.__init__',
                                                                                                                                             'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount_DeleteAccount_Error': ( 'classes/domoaccount.html#domoaccount_deleteaccount_error',
                                                                                                                      'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount_DeleteAccount_Error.__init__': ( 'classes/domoaccount.html#domoaccount_deleteaccount_error.__init__',
                                                                                                                               'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount_UpdateName_Error': ( 'classes/domoaccount.html#domoaccount_updatename_error',
                                                                                                                   'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccount_UpdateName_Error.__init__': ( 'classes/domoaccount.html#domoaccount_updatename_error.__init__',
                                                                                                                            'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccounts': ( 'classes/domoaccount.html#domoaccounts',
                                                                                                   'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccounts._get_accounts_accountsapi': ( 'classes/domoaccount.html#domoaccounts._get_accounts_accountsapi',
                                                                                                                             'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccounts._get_accounts_queryapi': ( 'classes/domoaccount.html#domoaccounts._get_accounts_queryapi',
                                                                                                                          'domolibrary/classes/DomoAccount.py'),
                                                 'domolibrary.classes.DomoAccount.DomoAccounts.get_accounts': ( 'classes/domoaccount.html#domoaccounts.get_accounts',
                                                                                                                'domolibrary/classes/DomoAccount.py')},
            'domolibrary.classes.DomoActivityLog': { 'domolibrary.classes.DomoActivityLog.ActivityLog_ObjectType': ( 'classes/domoactivitylog.html#activitylog_objecttype',
                                                                                                                     'domolibrary/classes/DomoActivityLog.py'),
                                                     'domolibrary.classes.DomoActivityLog.DomoActivityLog': ( 'classes/domoactivitylog.html#domoactivitylog',
                                                                                                              'domolibrary/classes/DomoActivityLog.py'),
                                                     'domolibrary.classes.DomoActivityLog.DomoActivityLog._process_activity_log_row': ( 'classes/domoactivitylog.html#domoactivitylog._process_activity_log_row',
                                                                                                                                        'domolibrary/classes/DomoActivityLog.py'),
                                                     'domolibrary.classes.DomoActivityLog.DomoActivityLog.get_activity_log': ( 'classes/domoactivitylog.html#domoactivitylog.get_activity_log',
                                                                                                                               'domolibrary/classes/DomoActivityLog.py')},
            'domolibrary.classes.DomoApplication': { 'domolibrary.classes.DomoApplication.DomoApplication': ( 'classes/domoapplication.html#domoapplication',
                                                                                                              'domolibrary/classes/DomoApplication.py'),
                                                     'domolibrary.classes.DomoApplication.DomoApplication._from_json': ( 'classes/domoapplication.html#domoapplication._from_json',
                                                                                                                         'domolibrary/classes/DomoApplication.py'),
                                                     'domolibrary.classes.DomoApplication.DomoApplication.find_next_job_schedule': ( 'classes/domoapplication.html#domoapplication.find_next_job_schedule',
                                                                                                                                     'domolibrary/classes/DomoApplication.py'),
                                                     'domolibrary.classes.DomoApplication.DomoApplication.get_all_schedules': ( 'classes/domoapplication.html#domoapplication.get_all_schedules',
                                                                                                                                'domolibrary/classes/DomoApplication.py'),
                                                     'domolibrary.classes.DomoApplication.DomoApplication.get_from_id': ( 'classes/domoapplication.html#domoapplication.get_from_id',
                                                                                                                          'domolibrary/classes/DomoApplication.py'),
                                                     'domolibrary.classes.DomoApplication.DomoApplication.get_jobs': ( 'classes/domoapplication.html#domoapplication.get_jobs',
                                                                                                                       'domolibrary/classes/DomoApplication.py')},
            'domolibrary.classes.DomoBootstrap': { 'domolibrary.classes.DomoBootstrap.DomoBootstrap': ( 'classes/domobootstrap.html#domobootstrap',
                                                                                                        'domolibrary/classes/DomoBootstrap.py'),
                                                   'domolibrary.classes.DomoBootstrap.DomoBootstrap.get_all': ( 'classes/domobootstrap.html#domobootstrap.get_all',
                                                                                                                'domolibrary/classes/DomoBootstrap.py'),
                                                   'domolibrary.classes.DomoBootstrap.DomoBootstrap.get_features': ( 'classes/domobootstrap.html#domobootstrap.get_features',
                                                                                                                     'domolibrary/classes/DomoBootstrap.py'),
                                                   'domolibrary.classes.DomoBootstrap.DomoBootstrap.get_pages': ( 'classes/domobootstrap.html#domobootstrap.get_pages',
                                                                                                                  'domolibrary/classes/DomoBootstrap.py'),
                                                   'domolibrary.classes.DomoBootstrap.DomoBootstrap.is_group_ownership_beta': ( 'classes/domobootstrap.html#domobootstrap.is_group_ownership_beta',
                                                                                                                                'domolibrary/classes/DomoBootstrap.py'),
                                                   'domolibrary.classes.DomoBootstrap.DomoBootstrap_Feature': ( 'classes/domobootstrap.html#domobootstrap_feature',
                                                                                                                'domolibrary/classes/DomoBootstrap.py'),
                                                   'domolibrary.classes.DomoBootstrap.DomoBootstrap_Feature._from_json_bootstrap': ( 'classes/domobootstrap.html#domobootstrap_feature._from_json_bootstrap',
                                                                                                                                     'domolibrary/classes/DomoBootstrap.py')},
            'domolibrary.classes.DomoCard': { 'domolibrary.classes.DomoCard.DomoCard': ( 'classes/domocard.html#domocard',
                                                                                         'domolibrary/classes/DomoCard.py'),
                                              'domolibrary.classes.DomoCard.DomoCard.__post_init__': ( 'classes/domocard.html#domocard.__post_init__',
                                                                                                       'domolibrary/classes/DomoCard.py'),
                                              'domolibrary.classes.DomoCard.DomoCard._from_json': ( 'classes/domocard.html#domocard._from_json',
                                                                                                    'domolibrary/classes/DomoCard.py'),
                                              'domolibrary.classes.DomoCard.DomoCard.display_url': ( 'classes/domocard.html#domocard.display_url',
                                                                                                     'domolibrary/classes/DomoCard.py'),
                                              'domolibrary.classes.DomoCard.DomoCard.get_by_id': ( 'classes/domocard.html#domocard.get_by_id',
                                                                                                   'domolibrary/classes/DomoCard.py'),
                                              'domolibrary.classes.DomoCard.DomoCard.share': ( 'classes/domocard.html#domocard.share',
                                                                                               'domolibrary/classes/DomoCard.py')},
            'domolibrary.classes.DomoCertification': { 'domolibrary.classes.DomoCertification.DomoCertification': ( 'classes/domocertification.html#domocertification',
                                                                                                                    'domolibrary/classes/DomoCertification.py'),
                                                       'domolibrary.classes.DomoCertification.DomoCertification._from_json': ( 'classes/domocertification.html#domocertification._from_json',
                                                                                                                               'domolibrary/classes/DomoCertification.py'),
                                                       'domolibrary.classes.DomoCertification.DomoCertificationState': ( 'classes/domocertification.html#domocertificationstate',
                                                                                                                         'domolibrary/classes/DomoCertification.py')},
            'domolibrary.classes.DomoDatacenter': { 'domolibrary.classes.DomoDatacenter.DomoDatacenter': ( 'classes/domodatacenter.html#domodatacenter',
                                                                                                           'domolibrary/classes/DomoDatacenter.py'),
                                                    'domolibrary.classes.DomoDatacenter.DomoDatacenter.get_accounts': ( 'classes/domodatacenter.html#domodatacenter.get_accounts',
                                                                                                                        'domolibrary/classes/DomoDatacenter.py'),
                                                    'domolibrary.classes.DomoDatacenter.DomoDatacenter.get_cards_admin_summary': ( 'classes/domodatacenter.html#domodatacenter.get_cards_admin_summary',
                                                                                                                                   'domolibrary/classes/DomoDatacenter.py'),
                                                    'domolibrary.classes.DomoDatacenter.DomoDatacenter.get_lineage_upstream': ( 'classes/domodatacenter.html#domodatacenter.get_lineage_upstream',
                                                                                                                                'domolibrary/classes/DomoDatacenter.py'),
                                                    'domolibrary.classes.DomoDatacenter.DomoDatacenter.search_cards': ( 'classes/domodatacenter.html#domodatacenter.search_cards',
                                                                                                                        'domolibrary/classes/DomoDatacenter.py'),
                                                    'domolibrary.classes.DomoDatacenter.DomoDatacenter.search_datacenter': ( 'classes/domodatacenter.html#domodatacenter.search_datacenter',
                                                                                                                             'domolibrary/classes/DomoDatacenter.py'),
                                                    'domolibrary.classes.DomoDatacenter.DomoDatacenter.search_datasets': ( 'classes/domodatacenter.html#domodatacenter.search_datasets',
                                                                                                                           'domolibrary/classes/DomoDatacenter.py'),
                                                    'domolibrary.classes.DomoDatacenter.LineageTypes_Enum': ( 'classes/domodatacenter.html#lineagetypes_enum',
                                                                                                              'domolibrary/classes/DomoDatacenter.py')},
            'domolibrary.classes.DomoDataflow': { 'domolibrary.classes.DomoDataflow.DomoDataflow': ( 'classes/domodataflow.html#domodataflow',
                                                                                                     'domolibrary/classes/DomoDataflow.py'),
                                                  'domolibrary.classes.DomoDataflow.DomoDataflow.execute': ( 'classes/domodataflow.html#domodataflow.execute',
                                                                                                             'domolibrary/classes/DomoDataflow.py'),
                                                  'domolibrary.classes.DomoDataflow.DomoDataflow.get_from_id': ( 'classes/domodataflow.html#domodataflow.get_from_id',
                                                                                                                 'domolibrary/classes/DomoDataflow.py'),
                                                  'domolibrary.classes.DomoDataflow.DomoDataflow_Action': ( 'classes/domodataflow.html#domodataflow_action',
                                                                                                            'domolibrary/classes/DomoDataflow.py'),
                                                  'domolibrary.classes.DomoDataflow.DomoDataflow_Action._from_obj': ( 'classes/domodataflow.html#domodataflow_action._from_obj',
                                                                                                                      'domolibrary/classes/DomoDataflow.py'),
                                                  'domolibrary.classes.DomoDataflow.DomoDataflow_Action_Type': ( 'classes/domodataflow.html#domodataflow_action_type',
                                                                                                                 'domolibrary/classes/DomoDataflow.py')},
            'domolibrary.classes.DomoDataset': { 'domolibrary.classes.DomoDataset.DatasetSchema_InvalidSchema': ( 'classes/domodataset.html#datasetschema_invalidschema',
                                                                                                                  'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DatasetSchema_InvalidSchema.__init__': ( 'classes/domodataset.html#datasetschema_invalidschema.__init__',
                                                                                                                           'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DatasetSchema_Types': ( 'classes/domodataset.html#datasetschema_types',
                                                                                                          'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DatasetTags_SetTagsError': ( 'classes/domodataset.html#datasettags_settagserror',
                                                                                                               'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DatasetTags_SetTagsError.__init__': ( 'classes/domodataset.html#datasettags_settagserror.__init__',
                                                                                                                        'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset': ( 'classes/domodataset.html#domodataset',
                                                                                                  'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset.__post_init__': ( 'classes/domodataset.html#domodataset.__post_init__',
                                                                                                                'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset.create': ( 'classes/domodataset.html#domodataset.create',
                                                                                                         'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset.delete': ( 'classes/domodataset.html#domodataset.delete',
                                                                                                         'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset.delete_partition': ( 'classes/domodataset.html#domodataset.delete_partition',
                                                                                                                   'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset.display_url': ( 'classes/domodataset.html#domodataset.display_url',
                                                                                                              'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset.get_from_id': ( 'classes/domodataset.html#domodataset.get_from_id',
                                                                                                              'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset.index_dataset': ( 'classes/domodataset.html#domodataset.index_dataset',
                                                                                                                'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset.list_partitions': ( 'classes/domodataset.html#domodataset.list_partitions',
                                                                                                                  'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset.query_dataset_private': ( 'classes/domodataset.html#domodataset.query_dataset_private',
                                                                                                                        'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset.reset_dataset': ( 'classes/domodataset.html#domodataset.reset_dataset',
                                                                                                                'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset.share': ( 'classes/domodataset.html#domodataset.share',
                                                                                                        'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset.upload_data': ( 'classes/domodataset.html#domodataset.upload_data',
                                                                                                              'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset_CreateDataset_Error': ( 'classes/domodataset.html#domodataset_createdataset_error',
                                                                                                                      'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset_CreateDataset_Error.__init__': ( 'classes/domodataset.html#domodataset_createdataset_error.__init__',
                                                                                                                               'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset_DeleteDataset_Error': ( 'classes/domodataset.html#domodataset_deletedataset_error',
                                                                                                                      'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset_DeleteDataset_Error.__init__': ( 'classes/domodataset.html#domodataset_deletedataset_error.__init__',
                                                                                                                               'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset_Schema': ( 'classes/domodataset.html#domodataset_schema',
                                                                                                         'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset_Schema._test_missing_columns': ( 'classes/domodataset.html#domodataset_schema._test_missing_columns',
                                                                                                                               'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset_Schema.add_col': ( 'classes/domodataset.html#domodataset_schema.add_col',
                                                                                                                 'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset_Schema.alter_schema': ( 'classes/domodataset.html#domodataset_schema.alter_schema',
                                                                                                                      'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset_Schema.get': ( 'classes/domodataset.html#domodataset_schema.get',
                                                                                                             'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset_Schema.remove_col': ( 'classes/domodataset.html#domodataset_schema.remove_col',
                                                                                                                    'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset_Schema.to_dict': ( 'classes/domodataset.html#domodataset_schema.to_dict',
                                                                                                                 'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset_Schema_Column': ( 'classes/domodataset.html#domodataset_schema_column',
                                                                                                                'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset_Schema_Column.__eq__': ( 'classes/domodataset.html#domodataset_schema_column.__eq__',
                                                                                                                       'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset_Schema_Column._from_json': ( 'classes/domodataset.html#domodataset_schema_column._from_json',
                                                                                                                           'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset_Schema_Column.to_dict': ( 'classes/domodataset.html#domodataset_schema_column.to_dict',
                                                                                                                        'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset_Tags': ( 'classes/domodataset.html#domodataset_tags',
                                                                                                       'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset_Tags.add': ( 'classes/domodataset.html#domodataset_tags.add',
                                                                                                           'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset_Tags.get': ( 'classes/domodataset.html#domodataset_tags.get',
                                                                                                           'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset_Tags.remove': ( 'classes/domodataset.html#domodataset_tags.remove',
                                                                                                              'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.DomoDataset_Tags.set': ( 'classes/domodataset.html#domodataset_tags.set',
                                                                                                           'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.QueryExecutionError': ( 'classes/domodataset.html#queryexecutionerror',
                                                                                                          'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset.QueryExecutionError.__init__': ( 'classes/domodataset.html#queryexecutionerror.__init__',
                                                                                                                   'domolibrary/classes/DomoDataset.py'),
                                                 'domolibrary.classes.DomoDataset._have_prereqs': ( 'classes/domodataset.html#_have_prereqs',
                                                                                                    'domolibrary/classes/DomoDataset.py')},
            'domolibrary.classes.DomoGrant': { 'domolibrary.classes.DomoGrant.DomoGrant': ( 'classes/domogrant.html#domogrant',
                                                                                            'domolibrary/classes/DomoGrant.py'),
                                               'domolibrary.classes.DomoGrant.DomoGrant.__eq__': ( 'classes/domogrant.html#domogrant.__eq__',
                                                                                                   'domolibrary/classes/DomoGrant.py'),
                                               'domolibrary.classes.DomoGrant.DomoGrant.__post_init__': ( 'classes/domogrant.html#domogrant.__post_init__',
                                                                                                          'domolibrary/classes/DomoGrant.py'),
                                               'domolibrary.classes.DomoGrant.DomoGrant._from_json': ( 'classes/domogrant.html#domogrant._from_json',
                                                                                                       'domolibrary/classes/DomoGrant.py'),
                                               'domolibrary.classes.DomoGrant.DomoGrants': ( 'classes/domogrant.html#domogrants',
                                                                                             'domolibrary/classes/DomoGrant.py'),
                                               'domolibrary.classes.DomoGrant.DomoGrants.get_grants': ( 'classes/domogrant.html#domogrants.get_grants',
                                                                                                        'domolibrary/classes/DomoGrant.py')},
            'domolibrary.classes.DomoGroup': { 'domolibrary.classes.DomoGroup.DomoGroup': ( 'classes/domogroup.html#domogroup',
                                                                                            'domolibrary/classes/DomoGroup.py'),
                                               'domolibrary.classes.DomoGroup.DomoGroup.__post_init__': ( 'classes/domogroup.html#domogroup.__post_init__',
                                                                                                          'domolibrary/classes/DomoGroup.py'),
                                               'domolibrary.classes.DomoGroup.DomoGroup._from_group_json': ( 'classes/domogroup.html#domogroup._from_group_json',
                                                                                                             'domolibrary/classes/DomoGroup.py'),
                                               'domolibrary.classes.DomoGroup.DomoGroup._from_grouplist_json': ( 'classes/domogroup.html#domogroup._from_grouplist_json',
                                                                                                                 'domolibrary/classes/DomoGroup.py'),
                                               'domolibrary.classes.DomoGroup.DomoGroup._groups_to_domo_group': ( 'classes/domogroup.html#domogroup._groups_to_domo_group',
                                                                                                                  'domolibrary/classes/DomoGroup.py'),
                                               'domolibrary.classes.DomoGroup.DomoGroup.create_from_name': ( 'classes/domogroup.html#domogroup.create_from_name',
                                                                                                             'domolibrary/classes/DomoGroup.py'),
                                               'domolibrary.classes.DomoGroup.DomoGroup.get_by_id': ( 'classes/domogroup.html#domogroup.get_by_id',
                                                                                                      'domolibrary/classes/DomoGroup.py'),
                                               'domolibrary.classes.DomoGroup.DomoGroup.search_by_name': ( 'classes/domogroup.html#domogroup.search_by_name',
                                                                                                           'domolibrary/classes/DomoGroup.py'),
                                               'domolibrary.classes.DomoGroup.DomoGroup.update_metadata': ( 'classes/domogroup.html#domogroup.update_metadata',
                                                                                                            'domolibrary/classes/DomoGroup.py'),
                                               'domolibrary.classes.DomoGroup.DomoGroup.upsert': ( 'classes/domogroup.html#domogroup.upsert',
                                                                                                   'domolibrary/classes/DomoGroup.py'),
                                               'domolibrary.classes.DomoGroup.DomoGroups': ( 'classes/domogroup.html#domogroups',
                                                                                             'domolibrary/classes/DomoGroup.py'),
                                               'domolibrary.classes.DomoGroup.DomoGroups.__init__': ( 'classes/domogroup.html#domogroups.__init__',
                                                                                                      'domolibrary/classes/DomoGroup.py'),
                                               'domolibrary.classes.DomoGroup.DomoGroups._groups_to_domo_group': ( 'classes/domogroup.html#domogroups._groups_to_domo_group',
                                                                                                                   'domolibrary/classes/DomoGroup.py'),
                                               'domolibrary.classes.DomoGroup.DomoGroups.get_all_groups': ( 'classes/domogroup.html#domogroups.get_all_groups',
                                                                                                            'domolibrary/classes/DomoGroup.py'),
                                               'domolibrary.classes.DomoGroup.GroupMembership': ( 'classes/domogroup.html#groupmembership',
                                                                                                  'domolibrary/classes/DomoGroup.py'),
                                               'domolibrary.classes.DomoGroup.GroupMembership.__init__': ( 'classes/domogroup.html#groupmembership.__init__',
                                                                                                           'domolibrary/classes/DomoGroup.py'),
                                               'domolibrary.classes.DomoGroup.GroupMembership._add_member': ( 'classes/domogroup.html#groupmembership._add_member',
                                                                                                              'domolibrary/classes/DomoGroup.py'),
                                               'domolibrary.classes.DomoGroup.GroupMembership._add_owner': ( 'classes/domogroup.html#groupmembership._add_owner',
                                                                                                             'domolibrary/classes/DomoGroup.py'),
                                               'domolibrary.classes.DomoGroup.GroupMembership._add_to_list': ( 'classes/domogroup.html#groupmembership._add_to_list',
                                                                                                               'domolibrary/classes/DomoGroup.py'),
                                               'domolibrary.classes.DomoGroup.GroupMembership._remove_member': ( 'classes/domogroup.html#groupmembership._remove_member',
                                                                                                                 'domolibrary/classes/DomoGroup.py'),
                                               'domolibrary.classes.DomoGroup.GroupMembership._remove_owner': ( 'classes/domogroup.html#groupmembership._remove_owner',
                                                                                                                'domolibrary/classes/DomoGroup.py'),
                                               'domolibrary.classes.DomoGroup.GroupMembership._reset_obj': ( 'classes/domogroup.html#groupmembership._reset_obj',
                                                                                                             'domolibrary/classes/DomoGroup.py'),
                                               'domolibrary.classes.DomoGroup.GroupMembership._update_group_access': ( 'classes/domogroup.html#groupmembership._update_group_access',
                                                                                                                       'domolibrary/classes/DomoGroup.py'),
                                               'domolibrary.classes.DomoGroup.GroupMembership.add_members': ( 'classes/domogroup.html#groupmembership.add_members',
                                                                                                              'domolibrary/classes/DomoGroup.py'),
                                               'domolibrary.classes.DomoGroup.GroupMembership.add_owners': ( 'classes/domogroup.html#groupmembership.add_owners',
                                                                                                             'domolibrary/classes/DomoGroup.py'),
                                               'domolibrary.classes.DomoGroup.GroupMembership.get_members': ( 'classes/domogroup.html#groupmembership.get_members',
                                                                                                              'domolibrary/classes/DomoGroup.py'),
                                               'domolibrary.classes.DomoGroup.GroupMembership.get_owners': ( 'classes/domogroup.html#groupmembership.get_owners',
                                                                                                             'domolibrary/classes/DomoGroup.py'),
                                               'domolibrary.classes.DomoGroup.GroupMembership.remove_members': ( 'classes/domogroup.html#groupmembership.remove_members',
                                                                                                                 'domolibrary/classes/DomoGroup.py'),
                                               'domolibrary.classes.DomoGroup.GroupMembership.remove_owners': ( 'classes/domogroup.html#groupmembership.remove_owners',
                                                                                                                'domolibrary/classes/DomoGroup.py'),
                                               'domolibrary.classes.DomoGroup.GroupMembership.set_members': ( 'classes/domogroup.html#groupmembership.set_members',
                                                                                                              'domolibrary/classes/DomoGroup.py'),
                                               'domolibrary.classes.DomoGroup.GroupMembership.set_owners': ( 'classes/domogroup.html#groupmembership.set_owners',
                                                                                                             'domolibrary/classes/DomoGroup.py'),
                                               'domolibrary.classes.DomoGroup.UpdateGroupMembership': ( 'classes/domogroup.html#updategroupmembership',
                                                                                                        'domolibrary/classes/DomoGroup.py'),
                                               'domolibrary.classes.DomoGroup.UpdateGroupMembership.__init__': ( 'classes/domogroup.html#updategroupmembership.__init__',
                                                                                                                 'domolibrary/classes/DomoGroup.py')},
            'domolibrary.classes.DomoInstanceConfig': { 'domolibrary.classes.DomoInstanceConfig.DomoInstanceConfig': ( 'classes/domoinstanceconfig.html#domoinstanceconfig',
                                                                                                                       'domolibrary/classes/DomoInstanceConfig.py'),
                                                        'domolibrary.classes.DomoInstanceConfig.DomoInstanceConfig.get_allowlist': ( 'classes/domoinstanceconfig.html#domoinstanceconfig.get_allowlist',
                                                                                                                                     'domolibrary/classes/DomoInstanceConfig.py'),
                                                        'domolibrary.classes.DomoInstanceConfig.DomoInstanceConfig.get_applications': ( 'classes/domoinstanceconfig.html#domoinstanceconfig.get_applications',
                                                                                                                                        'domolibrary/classes/DomoInstanceConfig.py'),
                                                        'domolibrary.classes.DomoInstanceConfig.DomoInstanceConfig.get_authorized_domains': ( 'classes/domoinstanceconfig.html#domoinstanceconfig.get_authorized_domains',
                                                                                                                                              'domolibrary/classes/DomoInstanceConfig.py'),
                                                        'domolibrary.classes.DomoInstanceConfig.DomoInstanceConfig.get_grants': ( 'classes/domoinstanceconfig.html#domoinstanceconfig.get_grants',
                                                                                                                                  'domolibrary/classes/DomoInstanceConfig.py'),
                                                        'domolibrary.classes.DomoInstanceConfig.DomoInstanceConfig.get_publications': ( 'classes/domoinstanceconfig.html#domoinstanceconfig.get_publications',
                                                                                                                                        'domolibrary/classes/DomoInstanceConfig.py'),
                                                        'domolibrary.classes.DomoInstanceConfig.DomoInstanceConfig.get_roles': ( 'classes/domoinstanceconfig.html#domoinstanceconfig.get_roles',
                                                                                                                                 'domolibrary/classes/DomoInstanceConfig.py'),
                                                        'domolibrary.classes.DomoInstanceConfig.DomoInstanceConfig.set_allowlist': ( 'classes/domoinstanceconfig.html#domoinstanceconfig.set_allowlist',
                                                                                                                                     'domolibrary/classes/DomoInstanceConfig.py'),
                                                        'domolibrary.classes.DomoInstanceConfig.DomoInstanceConfig.set_authorized_domains': ( 'classes/domoinstanceconfig.html#domoinstanceconfig.set_authorized_domains',
                                                                                                                                              'domolibrary/classes/DomoInstanceConfig.py'),
                                                        'domolibrary.classes.DomoInstanceConfig.DomoInstanceConfig.upsert_allowlist': ( 'classes/domoinstanceconfig.html#domoinstanceconfig.upsert_allowlist',
                                                                                                                                        'domolibrary/classes/DomoInstanceConfig.py'),
                                                        'domolibrary.classes.DomoInstanceConfig.DomoInstanceConfig.upsert_authorized_domains': ( 'classes/domoinstanceconfig.html#domoinstanceconfig.upsert_authorized_domains',
                                                                                                                                                 'domolibrary/classes/DomoInstanceConfig.py')},
            'domolibrary.classes.DomoJob': { 'domolibrary.classes.DomoJob.DomoJob': ( 'classes/domojob.html#domojob',
                                                                                      'domolibrary/classes/DomoJob.py'),
                                             'domolibrary.classes.DomoJob.DomoJob._from_json': ( 'classes/domojob.html#domojob._from_json',
                                                                                                 'domolibrary/classes/DomoJob.py'),
                                             'domolibrary.classes.DomoJob.DomoJob.create_domostats_job': ( 'classes/domojob.html#domojob.create_domostats_job',
                                                                                                           'domolibrary/classes/DomoJob.py'),
                                             'domolibrary.classes.DomoJob.DomoJob.create_watchdog_job': ( 'classes/domojob.html#domojob.create_watchdog_job',
                                                                                                          'domolibrary/classes/DomoJob.py'),
                                             'domolibrary.classes.DomoJob.DomoJob.generate_watchdog_body': ( 'classes/domojob.html#domojob.generate_watchdog_body',
                                                                                                             'domolibrary/classes/DomoJob.py'),
                                             'domolibrary.classes.DomoJob.DomoJob.get_body': ( 'classes/domojob.html#domojob.get_body',
                                                                                               'domolibrary/classes/DomoJob.py'),
                                             'domolibrary.classes.DomoJob.DomoJob.update_job': ( 'classes/domojob.html#domojob.update_job',
                                                                                                 'domolibrary/classes/DomoJob.py'),
                                             'domolibrary.classes.DomoJob.DomoTrigger': ( 'classes/domojob.html#domotrigger',
                                                                                          'domolibrary/classes/DomoJob.py'),
                                             'domolibrary.classes.DomoJob.DomoTrigger_Schedule': ( 'classes/domojob.html#domotrigger_schedule',
                                                                                                   'domolibrary/classes/DomoJob.py'),
                                             'domolibrary.classes.DomoJob.DomoTrigger_Schedule._from_str': ( 'classes/domojob.html#domotrigger_schedule._from_str',
                                                                                                             'domolibrary/classes/DomoJob.py'),
                                             'domolibrary.classes.DomoJob.DomoTrigger_Schedule.to_obj': ( 'classes/domojob.html#domotrigger_schedule.to_obj',
                                                                                                          'domolibrary/classes/DomoJob.py'),
                                             'domolibrary.classes.DomoJob.DomoTrigger_Schedule.to_schedule_obj': ( 'classes/domojob.html#domotrigger_schedule.to_schedule_obj',
                                                                                                                   'domolibrary/classes/DomoJob.py'),
                                             'domolibrary.classes.DomoJob.WatchDogType': ( 'classes/domojob.html#watchdogtype',
                                                                                           'domolibrary/classes/DomoJob.py')},
            'domolibrary.classes.DomoLineage': { 'domolibrary.classes.DomoLineage.DomoLineage': ( 'classes/domolineage.html#domolineage',
                                                                                                  'domolibrary/classes/DomoLineage.py'),
                                                 'domolibrary.classes.DomoLineage.DomoLineage.__post_init__': ( 'classes/domolineage.html#domolineage.__post_init__',
                                                                                                                'domolibrary/classes/DomoLineage.py'),
                                                 'domolibrary.classes.DomoLineage.DomoLineage._flatten_lineage': ( 'classes/domolineage.html#domolineage._flatten_lineage',
                                                                                                                   'domolibrary/classes/DomoLineage.py'),
                                                 'domolibrary.classes.DomoLineage.DomoLineage._get_content_list_ls': ( 'classes/domolineage.html#domolineage._get_content_list_ls',
                                                                                                                       'domolibrary/classes/DomoLineage.py'),
                                                 'domolibrary.classes.DomoLineage.DomoLineage._get_page_card_ids': ( 'classes/domolineage.html#domolineage._get_page_card_ids',
                                                                                                                     'domolibrary/classes/DomoLineage.py'),
                                                 'domolibrary.classes.DomoLineage.DomoLineage._reset_lineage_and_sync_parent': ( 'classes/domolineage.html#domolineage._reset_lineage_and_sync_parent',
                                                                                                                                 'domolibrary/classes/DomoLineage.py'),
                                                 'domolibrary.classes.DomoLineage.DomoLineage.get': ( 'classes/domolineage.html#domolineage.get',
                                                                                                      'domolibrary/classes/DomoLineage.py'),
                                                 'domolibrary.classes.DomoLineage.DomoLineage.get_entity_lineage_upstream': ( 'classes/domolineage.html#domolineage.get_entity_lineage_upstream',
                                                                                                                              'domolibrary/classes/DomoLineage.py'),
                                                 'domolibrary.classes.DomoLineage.DomoLineage_Type': ( 'classes/domolineage.html#domolineage_type',
                                                                                                       'domolibrary/classes/DomoLineage.py')},
            'domolibrary.classes.DomoPDP': { 'domolibrary.classes.DomoPDP.Dataset_PDP_Policies': ( 'classes/domopdp.html#dataset_pdp_policies',
                                                                                                   'domolibrary/classes/DomoPDP.py'),
                                             'domolibrary.classes.DomoPDP.Dataset_PDP_Policies.__init__': ( 'classes/domopdp.html#dataset_pdp_policies.__init__',
                                                                                                            'domolibrary/classes/DomoPDP.py'),
                                             'domolibrary.classes.DomoPDP.Dataset_PDP_Policies.get_policies': ( 'classes/domopdp.html#dataset_pdp_policies.get_policies',
                                                                                                                'domolibrary/classes/DomoPDP.py'),
                                             'domolibrary.classes.DomoPDP.Dataset_PDP_Policies.search_pdp_policies': ( 'classes/domopdp.html#dataset_pdp_policies.search_pdp_policies',
                                                                                                                       'domolibrary/classes/DomoPDP.py'),
                                             'domolibrary.classes.DomoPDP.Dataset_PDP_Policies.toggle_dataset_pdp': ( 'classes/domopdp.html#dataset_pdp_policies.toggle_dataset_pdp',
                                                                                                                      'domolibrary/classes/DomoPDP.py'),
                                             'domolibrary.classes.DomoPDP.PDP_Parameter': ( 'classes/domopdp.html#pdp_parameter',
                                                                                            'domolibrary/classes/DomoPDP.py'),
                                             'domolibrary.classes.DomoPDP.PDP_Parameter.generate_body_from_parameter': ( 'classes/domopdp.html#pdp_parameter.generate_body_from_parameter',
                                                                                                                         'domolibrary/classes/DomoPDP.py'),
                                             'domolibrary.classes.DomoPDP.PDP_Parameter.generate_parameter_simple': ( 'classes/domopdp.html#pdp_parameter.generate_parameter_simple',
                                                                                                                      'domolibrary/classes/DomoPDP.py'),
                                             'domolibrary.classes.DomoPDP.PDP_Policy': ( 'classes/domopdp.html#pdp_policy',
                                                                                         'domolibrary/classes/DomoPDP.py'),
                                             'domolibrary.classes.DomoPDP.PDP_Policy._from_json': ( 'classes/domopdp.html#pdp_policy._from_json',
                                                                                                    'domolibrary/classes/DomoPDP.py'),
                                             'domolibrary.classes.DomoPDP.PDP_Policy.delete_policy': ( 'classes/domopdp.html#pdp_policy.delete_policy',
                                                                                                       'domolibrary/classes/DomoPDP.py'),
                                             'domolibrary.classes.DomoPDP.PDP_Policy.generate_body_from_policy': ( 'classes/domopdp.html#pdp_policy.generate_body_from_policy',
                                                                                                                   'domolibrary/classes/DomoPDP.py'),
                                             'domolibrary.classes.DomoPDP.PDP_Policy.upsert_policy': ( 'classes/domopdp.html#pdp_policy.upsert_policy',
                                                                                                       'domolibrary/classes/DomoPDP.py'),
                                             'domolibrary.classes.DomoPDP.SearchPDP_NotFound': ( 'classes/domopdp.html#searchpdp_notfound',
                                                                                                 'domolibrary/classes/DomoPDP.py'),
                                             'domolibrary.classes.DomoPDP.SearchPDP_NotFound.__init__': ( 'classes/domopdp.html#searchpdp_notfound.__init__',
                                                                                                          'domolibrary/classes/DomoPDP.py')},
            'domolibrary.classes.DomoPage': { 'domolibrary.classes.DomoPage.DomoPage': ( 'classes/domopage.html#domopage',
                                                                                         'domolibrary/classes/DomoPage.py'),
                                              'domolibrary.classes.DomoPage.DomoPage._from_adminsummary': ( 'classes/domopage.html#domopage._from_adminsummary',
                                                                                                            'domolibrary/classes/DomoPage.py'),
                                              'domolibrary.classes.DomoPage.DomoPage._from_bootstrap': ( 'classes/domopage.html#domopage._from_bootstrap',
                                                                                                         'domolibrary/classes/DomoPage.py'),
                                              'domolibrary.classes.DomoPage.DomoPage._from_content_stacks_v3': ( 'classes/domopage.html#domopage._from_content_stacks_v3',
                                                                                                                 'domolibrary/classes/DomoPage.py'),
                                              'domolibrary.classes.DomoPage.DomoPage._get_domo_groups': ( 'classes/domopage.html#domopage._get_domo_groups',
                                                                                                          'domolibrary/classes/DomoPage.py'),
                                              'domolibrary.classes.DomoPage.DomoPage._get_domo_owners_from_dd': ( 'classes/domopage.html#domopage._get_domo_owners_from_dd',
                                                                                                                  'domolibrary/classes/DomoPage.py'),
                                              'domolibrary.classes.DomoPage.DomoPage._get_domo_users': ( 'classes/domopage.html#domopage._get_domo_users',
                                                                                                         'domolibrary/classes/DomoPage.py'),
                                              'domolibrary.classes.DomoPage.DomoPage.display_url': ( 'classes/domopage.html#domopage.display_url',
                                                                                                     'domolibrary/classes/DomoPage.py'),
                                              'domolibrary.classes.DomoPage.DomoPage.get_accesslist': ( 'classes/domopage.html#domopage.get_accesslist',
                                                                                                        'domolibrary/classes/DomoPage.py'),
                                              'domolibrary.classes.DomoPage.DomoPage.get_by_id': ( 'classes/domopage.html#domopage.get_by_id',
                                                                                                   'domolibrary/classes/DomoPage.py'),
                                              'domolibrary.classes.DomoPage.DomoPage.get_cards': ( 'classes/domopage.html#domopage.get_cards',
                                                                                                   'domolibrary/classes/DomoPage.py'),
                                              'domolibrary.classes.DomoPage.DomoPage.get_datasets': ( 'classes/domopage.html#domopage.get_datasets',
                                                                                                      'domolibrary/classes/DomoPage.py'),
                                              'domolibrary.classes.DomoPage.DomoPage.share': ( 'classes/domopage.html#domopage.share',
                                                                                               'domolibrary/classes/DomoPage.py'),
                                              'domolibrary.classes.DomoPage.DomoPage.update_layout': ( 'classes/domopage.html#domopage.update_layout',
                                                                                                       'domolibrary/classes/DomoPage.py'),
                                              'domolibrary.classes.DomoPage.DomoPages': ( 'classes/domopage.html#domopages',
                                                                                          'domolibrary/classes/DomoPage.py'),
                                              'domolibrary.classes.DomoPage.DomoPages.get_pages': ( 'classes/domopage.html#domopages.get_pages',
                                                                                                    'domolibrary/classes/DomoPage.py'),
                                              'domolibrary.classes.DomoPage.PageLayout': ( 'classes/domopage.html#pagelayout',
                                                                                           'domolibrary/classes/DomoPage.py'),
                                              'domolibrary.classes.DomoPage.PageLayout._from_json': ( 'classes/domopage.html#pagelayout._from_json',
                                                                                                      'domolibrary/classes/DomoPage.py'),
                                              'domolibrary.classes.DomoPage.PageLayout.generate_new_background_body': ( 'classes/domopage.html#pagelayout.generate_new_background_body',
                                                                                                                        'domolibrary/classes/DomoPage.py'),
                                              'domolibrary.classes.DomoPage.PageLayout.get_body': ( 'classes/domopage.html#pagelayout.get_body',
                                                                                                    'domolibrary/classes/DomoPage.py'),
                                              'domolibrary.classes.DomoPage.PageLayoutBackground': ( 'classes/domopage.html#pagelayoutbackground',
                                                                                                     'domolibrary/classes/DomoPage.py'),
                                              'domolibrary.classes.DomoPage.PageLayoutBackground._from_json': ( 'classes/domopage.html#pagelayoutbackground._from_json',
                                                                                                                'domolibrary/classes/DomoPage.py'),
                                              'domolibrary.classes.DomoPage.PageLayoutBackground.get_body': ( 'classes/domopage.html#pagelayoutbackground.get_body',
                                                                                                              'domolibrary/classes/DomoPage.py'),
                                              'domolibrary.classes.DomoPage.PageLayoutCompact': ( 'classes/domopage.html#pagelayoutcompact',
                                                                                                  'domolibrary/classes/DomoPage.py'),
                                              'domolibrary.classes.DomoPage.PageLayoutCompact._from_json': ( 'classes/domopage.html#pagelayoutcompact._from_json',
                                                                                                             'domolibrary/classes/DomoPage.py'),
                                              'domolibrary.classes.DomoPage.PageLayoutContent': ( 'classes/domopage.html#pagelayoutcontent',
                                                                                                  'domolibrary/classes/DomoPage.py'),
                                              'domolibrary.classes.DomoPage.PageLayoutContent._from_json': ( 'classes/domopage.html#pagelayoutcontent._from_json',
                                                                                                             'domolibrary/classes/DomoPage.py'),
                                              'domolibrary.classes.DomoPage.PageLayoutContent.get_body': ( 'classes/domopage.html#pagelayoutcontent.get_body',
                                                                                                           'domolibrary/classes/DomoPage.py'),
                                              'domolibrary.classes.DomoPage.PageLayoutStandard': ( 'classes/domopage.html#pagelayoutstandard',
                                                                                                   'domolibrary/classes/DomoPage.py'),
                                              'domolibrary.classes.DomoPage.PageLayoutStandard._from_json': ( 'classes/domopage.html#pagelayoutstandard._from_json',
                                                                                                              'domolibrary/classes/DomoPage.py'),
                                              'domolibrary.classes.DomoPage.PageLayoutTemplate': ( 'classes/domopage.html#pagelayouttemplate',
                                                                                                   'domolibrary/classes/DomoPage.py'),
                                              'domolibrary.classes.DomoPage.PageLayoutTemplate._from_json': ( 'classes/domopage.html#pagelayouttemplate._from_json',
                                                                                                              'domolibrary/classes/DomoPage.py'),
                                              'domolibrary.classes.DomoPage.PageLayoutTemplate.get_body': ( 'classes/domopage.html#pagelayouttemplate.get_body',
                                                                                                            'domolibrary/classes/DomoPage.py')},
            'domolibrary.classes.DomoPublish': { 'domolibrary.classes.DomoPublish.DomoPublication': ( 'classes/domopublish.html#domopublication',
                                                                                                      'domolibrary/classes/DomoPublish.py'),
                                                 'domolibrary.classes.DomoPublish.DomoPublication.__post_init__': ( 'classes/domopublish.html#domopublication.__post_init__',
                                                                                                                    'domolibrary/classes/DomoPublish.py'),
                                                 'domolibrary.classes.DomoPublish.DomoPublication._from_json': ( 'classes/domopublish.html#domopublication._from_json',
                                                                                                                 'domolibrary/classes/DomoPublish.py'),
                                                 'domolibrary.classes.DomoPublish.DomoPublication.accept_invite_by_id': ( 'classes/domopublish.html#domopublication.accept_invite_by_id',
                                                                                                                          'domolibrary/classes/DomoPublish.py'),
                                                 'domolibrary.classes.DomoPublish.DomoPublication.convert_content_to_dataframe': ( 'classes/domopublish.html#domopublication.convert_content_to_dataframe',
                                                                                                                                   'domolibrary/classes/DomoPublish.py'),
                                                 'domolibrary.classes.DomoPublish.DomoPublication.convert_lineage_to_dataframe': ( 'classes/domopublish.html#domopublication.convert_lineage_to_dataframe',
                                                                                                                                   'domolibrary/classes/DomoPublish.py'),
                                                 'domolibrary.classes.DomoPublish.DomoPublication.create_publication': ( 'classes/domopublish.html#domopublication.create_publication',
                                                                                                                         'domolibrary/classes/DomoPublish.py'),
                                                 'domolibrary.classes.DomoPublish.DomoPublication.get_from_id': ( 'classes/domopublish.html#domopublication.get_from_id',
                                                                                                                  'domolibrary/classes/DomoPublish.py'),
                                                 'domolibrary.classes.DomoPublish.DomoPublication.get_subscription_invites_list': ( 'classes/domopublish.html#domopublication.get_subscription_invites_list',
                                                                                                                                    'domolibrary/classes/DomoPublish.py'),
                                                 'domolibrary.classes.DomoPublish.DomoPublication.update_publication': ( 'classes/domopublish.html#domopublication.update_publication',
                                                                                                                         'domolibrary/classes/DomoPublish.py'),
                                                 'domolibrary.classes.DomoPublish.DomoPublication_Content': ( 'classes/domopublish.html#domopublication_content',
                                                                                                              'domolibrary/classes/DomoPublish.py'),
                                                 'domolibrary.classes.DomoPublish.DomoPublication_Content._from_json': ( 'classes/domopublish.html#domopublication_content._from_json',
                                                                                                                         'domolibrary/classes/DomoPublish.py'),
                                                 'domolibrary.classes.DomoPublish.DomoPublication_Content.to_api_json': ( 'classes/domopublish.html#domopublication_content.to_api_json',
                                                                                                                          'domolibrary/classes/DomoPublish.py'),
                                                 'domolibrary.classes.DomoPublish.DomoPublication_Subscription': ( 'classes/domopublish.html#domopublication_subscription',
                                                                                                                   'domolibrary/classes/DomoPublish.py'),
                                                 'domolibrary.classes.DomoPublish.DomoPublication_Subscription._from_json': ( 'classes/domopublish.html#domopublication_subscription._from_json',
                                                                                                                              'domolibrary/classes/DomoPublish.py'),
                                                 'domolibrary.classes.DomoPublish.DomoPublication_UnexpectedContentType': ( 'classes/domopublish.html#domopublication_unexpectedcontenttype',
                                                                                                                            'domolibrary/classes/DomoPublish.py'),
                                                 'domolibrary.classes.DomoPublish.DomoPublication_UnexpectedContentType.__init__': ( 'classes/domopublish.html#domopublication_unexpectedcontenttype.__init__',
                                                                                                                                     'domolibrary/classes/DomoPublish.py'),
                                                 'domolibrary.classes.DomoPublish.DomoPublications': ( 'classes/domopublish.html#domopublications',
                                                                                                       'domolibrary/classes/DomoPublish.py'),
                                                 'domolibrary.classes.DomoPublish.DomoPublications.get_subscription_summaries': ( 'classes/domopublish.html#domopublications.get_subscription_summaries',
                                                                                                                                  'domolibrary/classes/DomoPublish.py'),
                                                 'domolibrary.classes.DomoPublish.DomoPublications.search_publications': ( 'classes/domopublish.html#domopublications.search_publications',
                                                                                                                           'domolibrary/classes/DomoPublish.py')},
            'domolibrary.classes.DomoRole': { 'domolibrary.classes.DomoRole.AddUser_Error': ( 'classes/domorole.html#adduser_error',
                                                                                              'domolibrary/classes/DomoRole.py'),
                                              'domolibrary.classes.DomoRole.AddUser_Error.__init__': ( 'classes/domorole.html#adduser_error.__init__',
                                                                                                       'domolibrary/classes/DomoRole.py'),
                                              'domolibrary.classes.DomoRole.CreateRole_Error': ( 'classes/domorole.html#createrole_error',
                                                                                                 'domolibrary/classes/DomoRole.py'),
                                              'domolibrary.classes.DomoRole.CreateRole_Error.__init__': ( 'classes/domorole.html#createrole_error.__init__',
                                                                                                          'domolibrary/classes/DomoRole.py'),
                                              'domolibrary.classes.DomoRole.DeleteRole_Error': ( 'classes/domorole.html#deleterole_error',
                                                                                                 'domolibrary/classes/DomoRole.py'),
                                              'domolibrary.classes.DomoRole.DeleteRole_Error.__init__': ( 'classes/domorole.html#deleterole_error.__init__',
                                                                                                          'domolibrary/classes/DomoRole.py'),
                                              'domolibrary.classes.DomoRole.DomoRole': ( 'classes/domorole.html#domorole',
                                                                                         'domolibrary/classes/DomoRole.py'),
                                              'domolibrary.classes.DomoRole.DomoRole.__post_init__': ( 'classes/domorole.html#domorole.__post_init__',
                                                                                                       'domolibrary/classes/DomoRole.py'),
                                              'domolibrary.classes.DomoRole.DomoRole._from_json': ( 'classes/domorole.html#domorole._from_json',
                                                                                                    'domolibrary/classes/DomoRole.py'),
                                              'domolibrary.classes.DomoRole.DomoRole._valid_grant_ls': ( 'classes/domorole.html#domorole._valid_grant_ls',
                                                                                                         'domolibrary/classes/DomoRole.py'),
                                              'domolibrary.classes.DomoRole.DomoRole.add_user': ( 'classes/domorole.html#domorole.add_user',
                                                                                                  'domolibrary/classes/DomoRole.py'),
                                              'domolibrary.classes.DomoRole.DomoRole.delete_role': ( 'classes/domorole.html#domorole.delete_role',
                                                                                                     'domolibrary/classes/DomoRole.py'),
                                              'domolibrary.classes.DomoRole.DomoRole.get_grants': ( 'classes/domorole.html#domorole.get_grants',
                                                                                                    'domolibrary/classes/DomoRole.py'),
                                              'domolibrary.classes.DomoRole.DomoRole.get_membership': ( 'classes/domorole.html#domorole.get_membership',
                                                                                                        'domolibrary/classes/DomoRole.py'),
                                              'domolibrary.classes.DomoRole.DomoRole.set_as_default_role': ( 'classes/domorole.html#domorole.set_as_default_role',
                                                                                                             'domolibrary/classes/DomoRole.py'),
                                              'domolibrary.classes.DomoRole.DomoRole.set_grants': ( 'classes/domorole.html#domorole.set_grants',
                                                                                                    'domolibrary/classes/DomoRole.py'),
                                              'domolibrary.classes.DomoRole.DomoRole.update_role_metadata': ( 'classes/domorole.html#domorole.update_role_metadata',
                                                                                                              'domolibrary/classes/DomoRole.py'),
                                              'domolibrary.classes.DomoRole.DomoRoles': ( 'classes/domorole.html#domoroles',
                                                                                          'domolibrary/classes/DomoRole.py'),
                                              'domolibrary.classes.DomoRole.DomoRoles.create_role': ( 'classes/domorole.html#domoroles.create_role',
                                                                                                      'domolibrary/classes/DomoRole.py'),
                                              'domolibrary.classes.DomoRole.DomoRoles.get_roles': ( 'classes/domorole.html#domoroles.get_roles',
                                                                                                    'domolibrary/classes/DomoRole.py'),
                                              'domolibrary.classes.DomoRole.DomoRoles.search_role': ( 'classes/domorole.html#domoroles.search_role',
                                                                                                      'domolibrary/classes/DomoRole.py'),
                                              'domolibrary.classes.DomoRole.DomoRoles.upsert_role': ( 'classes/domorole.html#domoroles.upsert_role',
                                                                                                      'domolibrary/classes/DomoRole.py'),
                                              'domolibrary.classes.DomoRole.SearchRole_NotFound': ( 'classes/domorole.html#searchrole_notfound',
                                                                                                    'domolibrary/classes/DomoRole.py'),
                                              'domolibrary.classes.DomoRole.SearchRole_NotFound.__init__': ( 'classes/domorole.html#searchrole_notfound.__init__',
                                                                                                             'domolibrary/classes/DomoRole.py'),
                                              'domolibrary.classes.DomoRole.SetRoleGrants_MissingGrants': ( 'classes/domorole.html#setrolegrants_missinggrants',
                                                                                                            'domolibrary/classes/DomoRole.py'),
                                              'domolibrary.classes.DomoRole.SetRoleGrants_MissingGrants.__init__': ( 'classes/domorole.html#setrolegrants_missinggrants.__init__',
                                                                                                                     'domolibrary/classes/DomoRole.py')},
            'domolibrary.classes.DomoSandbox': { 'domolibrary.classes.DomoSandbox.DomoRepository': ( 'classes/domosandbox.html#domorepository',
                                                                                                     'domolibrary/classes/DomoSandbox.py'),
                                                 'domolibrary.classes.DomoSandbox.DomoRepository.__post_init__': ( 'classes/domosandbox.html#domorepository.__post_init__',
                                                                                                                   'domolibrary/classes/DomoSandbox.py'),
                                                 'domolibrary.classes.DomoSandbox.DomoRepository._from_json': ( 'classes/domosandbox.html#domorepository._from_json',
                                                                                                                'domolibrary/classes/DomoSandbox.py'),
                                                 'domolibrary.classes.DomoSandbox.DomoRepository.convert_lineage_to_dataframe': ( 'classes/domosandbox.html#domorepository.convert_lineage_to_dataframe',
                                                                                                                                  'domolibrary/classes/DomoSandbox.py'),
                                                 'domolibrary.classes.DomoSandbox.DomoRepository.get_from_id': ( 'classes/domosandbox.html#domorepository.get_from_id',
                                                                                                                 'domolibrary/classes/DomoSandbox.py'),
                                                 'domolibrary.classes.DomoSandbox.DomoSandbox': ( 'classes/domosandbox.html#domosandbox',
                                                                                                  'domolibrary/classes/DomoSandbox.py'),
                                                 'domolibrary.classes.DomoSandbox.DomoSandbox.get_repositories': ( 'classes/domosandbox.html#domosandbox.get_repositories',
                                                                                                                   'domolibrary/classes/DomoSandbox.py'),
                                                 'domolibrary.classes.DomoSandbox.InvalidRepositoryError': ( 'classes/domosandbox.html#invalidrepositoryerror',
                                                                                                             'domolibrary/classes/DomoSandbox.py')},
            'domolibrary.classes.DomoStream': { 'domolibrary.classes.DomoStream.DomoStream': ( 'classes/domostream.html#domostream',
                                                                                               'domolibrary/classes/DomoStream.py'),
                                                'domolibrary.classes.DomoStream.DomoStream.create_stream': ( 'classes/domostream.html#domostream.create_stream',
                                                                                                             'domolibrary/classes/DomoStream.py'),
                                                'domolibrary.classes.DomoStream.DomoStream.get_stream_by_id': ( 'classes/domostream.html#domostream.get_stream_by_id',
                                                                                                                'domolibrary/classes/DomoStream.py'),
                                                'domolibrary.classes.DomoStream.DomoStream.update_stream': ( 'classes/domostream.html#domostream.update_stream',
                                                                                                             'domolibrary/classes/DomoStream.py'),
                                                'domolibrary.classes.DomoStream.DomoStream.upsert_connector': ( 'classes/domostream.html#domostream.upsert_connector',
                                                                                                                'domolibrary/classes/DomoStream.py'),
                                                'domolibrary.classes.DomoStream.StreamConfig': ( 'classes/domostream.html#streamconfig',
                                                                                                 'domolibrary/classes/DomoStream.py')},
            'domolibrary.classes.DomoUser': { 'domolibrary.classes.DomoUser.CreateUser_MissingRole': ( 'classes/domouser.html#createuser_missingrole',
                                                                                                       'domolibrary/classes/DomoUser.py'),
                                              'domolibrary.classes.DomoUser.CreateUser_MissingRole.__init__': ( 'classes/domouser.html#createuser_missingrole.__init__',
                                                                                                                'domolibrary/classes/DomoUser.py'),
                                              'domolibrary.classes.DomoUser.DomoUser': ( 'classes/domouser.html#domouser',
                                                                                         'domolibrary/classes/DomoUser.py'),
                                              'domolibrary.classes.DomoUser.DomoUser.__eq__': ( 'classes/domouser.html#domouser.__eq__',
                                                                                                'domolibrary/classes/DomoUser.py'),
                                              'domolibrary.classes.DomoUser.DomoUser.__post_init__': ( 'classes/domouser.html#domouser.__post_init__',
                                                                                                       'domolibrary/classes/DomoUser.py'),
                                              'domolibrary.classes.DomoUser.DomoUser._from_bootstrap_json': ( 'classes/domouser.html#domouser._from_bootstrap_json',
                                                                                                              'domolibrary/classes/DomoUser.py'),
                                              'domolibrary.classes.DomoUser.DomoUser._from_search_json': ( 'classes/domouser.html#domouser._from_search_json',
                                                                                                           'domolibrary/classes/DomoUser.py'),
                                              'domolibrary.classes.DomoUser.DomoUser._from_virtual_json': ( 'classes/domouser.html#domouser._from_virtual_json',
                                                                                                            'domolibrary/classes/DomoUser.py'),
                                              'domolibrary.classes.DomoUser.DomoUser.get_by_id': ( 'classes/domouser.html#domouser.get_by_id',
                                                                                                   'domolibrary/classes/DomoUser.py'),
                                              'domolibrary.classes.DomoUser.DomoUser.request_password_reset': ( 'classes/domouser.html#domouser.request_password_reset',
                                                                                                                'domolibrary/classes/DomoUser.py'),
                                              'domolibrary.classes.DomoUser.DomoUser.reset_password': ( 'classes/domouser.html#domouser.reset_password',
                                                                                                        'domolibrary/classes/DomoUser.py'),
                                              'domolibrary.classes.DomoUser.DomoUser.set_user_landing_page': ( 'classes/domouser.html#domouser.set_user_landing_page',
                                                                                                               'domolibrary/classes/DomoUser.py'),
                                              'domolibrary.classes.DomoUser.DomoUser.update_properties': ( 'classes/domouser.html#domouser.update_properties',
                                                                                                           'domolibrary/classes/DomoUser.py'),
                                              'domolibrary.classes.DomoUser.DomoUsers': ( 'classes/domouser.html#domousers',
                                                                                          'domolibrary/classes/DomoUser.py'),
                                              'domolibrary.classes.DomoUser.DomoUsers._generate_logger': ( 'classes/domouser.html#domousers._generate_logger',
                                                                                                           'domolibrary/classes/DomoUser.py'),
                                              'domolibrary.classes.DomoUser.DomoUsers._users_to_domo_user': ( 'classes/domouser.html#domousers._users_to_domo_user',
                                                                                                              'domolibrary/classes/DomoUser.py'),
                                              'domolibrary.classes.DomoUser.DomoUsers._users_to_virtual_user': ( 'classes/domouser.html#domousers._users_to_virtual_user',
                                                                                                                 'domolibrary/classes/DomoUser.py'),
                                              'domolibrary.classes.DomoUser.DomoUsers.all_users': ( 'classes/domouser.html#domousers.all_users',
                                                                                                    'domolibrary/classes/DomoUser.py'),
                                              'domolibrary.classes.DomoUser.DomoUsers.by_email': ( 'classes/domouser.html#domousers.by_email',
                                                                                                   'domolibrary/classes/DomoUser.py'),
                                              'domolibrary.classes.DomoUser.DomoUsers.by_id': ( 'classes/domouser.html#domousers.by_id',
                                                                                                'domolibrary/classes/DomoUser.py'),
                                              'domolibrary.classes.DomoUser.DomoUsers.create_user': ( 'classes/domouser.html#domousers.create_user',
                                                                                                      'domolibrary/classes/DomoUser.py'),
                                              'domolibrary.classes.DomoUser.DomoUsers.upsert_user': ( 'classes/domouser.html#domousers.upsert_user',
                                                                                                      'domolibrary/classes/DomoUser.py'),
                                              'domolibrary.classes.DomoUser.DomoUsers.util_match_domo_users_to_emails': ( 'classes/domouser.html#domousers.util_match_domo_users_to_emails',
                                                                                                                          'domolibrary/classes/DomoUser.py'),
                                              'domolibrary.classes.DomoUser.DomoUsers.util_match_users_obj_to_emails': ( 'classes/domouser.html#domousers.util_match_users_obj_to_emails',
                                                                                                                         'domolibrary/classes/DomoUser.py'),
                                              'domolibrary.classes.DomoUser.DomoUsers.virtual_user_by_subscriber_instance': ( 'classes/domouser.html#domousers.virtual_user_by_subscriber_instance',
                                                                                                                              'domolibrary/classes/DomoUser.py')},
            'domolibrary.client.DomoAuth': { 'domolibrary.client.DomoAuth.DomoAuth': ( 'client/domoauth.html#domoauth',
                                                                                       'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth.DomoDeveloperAuth': ( 'client/domoauth.html#domodeveloperauth',
                                                                                                'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth.DomoDeveloperAuth.__init__': ( 'client/domoauth.html#domodeveloperauth.__init__',
                                                                                                         'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth.DomoDeveloperAuth.generate_auth_header': ( 'client/domoauth.html#domodeveloperauth.generate_auth_header',
                                                                                                                     'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth.DomoDeveloperAuth.get_auth_token': ( 'client/domoauth.html#domodeveloperauth.get_auth_token',
                                                                                                               'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth.DomoFullAuth': ( 'client/domoauth.html#domofullauth',
                                                                                           'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth.DomoFullAuth.generate_auth_header': ( 'client/domoauth.html#domofullauth.generate_auth_header',
                                                                                                                'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth.DomoFullAuth.get_auth_token': ( 'client/domoauth.html#domofullauth.get_auth_token',
                                                                                                          'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth.DomoTokenAuth': ( 'client/domoauth.html#domotokenauth',
                                                                                            'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth.DomoTokenAuth.generate_auth_header': ( 'client/domoauth.html#domotokenauth.generate_auth_header',
                                                                                                                 'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth.DomoTokenAuth.get_auth_token': ( 'client/domoauth.html#domotokenauth.get_auth_token',
                                                                                                           'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth.InvalidAuthTypeError': ( 'client/domoauth.html#invalidauthtypeerror',
                                                                                                   'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth.InvalidAuthTypeError.__init__': ( 'client/domoauth.html#invalidauthtypeerror.__init__',
                                                                                                            'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth.InvalidCredentialsError': ( 'client/domoauth.html#invalidcredentialserror',
                                                                                                      'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth.InvalidCredentialsError.__init__': ( 'client/domoauth.html#invalidcredentialserror.__init__',
                                                                                                               'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth.InvalidInstanceError': ( 'client/domoauth.html#invalidinstanceerror',
                                                                                                   'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth.InvalidInstanceError.__init__': ( 'client/domoauth.html#invalidinstanceerror.__init__',
                                                                                                            'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth.NoAccessTokenReturned': ( 'client/domoauth.html#noaccesstokenreturned',
                                                                                                    'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth.NoAccessTokenReturned.__init__': ( 'client/domoauth.html#noaccesstokenreturned.__init__',
                                                                                                             'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth._DomoAuth_Optional': ( 'client/domoauth.html#_domoauth_optional',
                                                                                                 'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth._DomoAuth_Optional.generate_auth_header': ( 'client/domoauth.html#_domoauth_optional.generate_auth_header',
                                                                                                                      'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth._DomoAuth_Optional.get_auth_token': ( 'client/domoauth.html#_domoauth_optional.get_auth_token',
                                                                                                                'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth._DomoAuth_Optional.print_is_token': ( 'client/domoauth.html#_domoauth_optional.print_is_token',
                                                                                                                'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth._DomoAuth_Required': ( 'client/domoauth.html#_domoauth_required',
                                                                                                 'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth._DomoAuth_Required.__post_init__': ( 'client/domoauth.html#_domoauth_required.__post_init__',
                                                                                                               'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth._DomoAuth_Required.set_manual_login': ( 'client/domoauth.html#_domoauth_required.set_manual_login',
                                                                                                                  'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth._DomoDeveloperAuth_Required': ( 'client/domoauth.html#_domodeveloperauth_required',
                                                                                                          'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth._DomoFullAuth_Required': ( 'client/domoauth.html#_domofullauth_required',
                                                                                                     'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth._DomoTokenAuth_Required': ( 'client/domoauth.html#_domotokenauth_required',
                                                                                                      'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth.get_developer_auth': ( 'client/domoauth.html#get_developer_auth',
                                                                                                 'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth.get_full_auth': ( 'client/domoauth.html#get_full_auth',
                                                                                            'domolibrary/client/DomoAuth.py'),
                                             'domolibrary.client.DomoAuth.test_access_token': ( 'client/domoauth.html#test_access_token',
                                                                                                'domolibrary/client/DomoAuth.py')},
            'domolibrary.client.DomoError': { 'domolibrary.client.DomoError.AuthNotProvidedError': ( 'client/domoerror.html#authnotprovidederror',
                                                                                                     'domolibrary/client/DomoError.py'),
                                              'domolibrary.client.DomoError.AuthNotProvidedError.__init__': ( 'client/domoerror.html#authnotprovidederror.__init__',
                                                                                                              'domolibrary/client/DomoError.py'),
                                              'domolibrary.client.DomoError.DatasetNotProvidedError': ( 'client/domoerror.html#datasetnotprovidederror',
                                                                                                        'domolibrary/client/DomoError.py'),
                                              'domolibrary.client.DomoError.DatasetNotProvidedError.__init__': ( 'client/domoerror.html#datasetnotprovidederror.__init__',
                                                                                                                 'domolibrary/client/DomoError.py'),
                                              'domolibrary.client.DomoError.DomoError': ( 'client/domoerror.html#domoerror',
                                                                                          'domolibrary/client/DomoError.py'),
                                              'domolibrary.client.DomoError.DomoError.__init__': ( 'client/domoerror.html#domoerror.__init__',
                                                                                                   'domolibrary/client/DomoError.py')},
            'domolibrary.client.Logger': { 'domolibrary.client.Logger.Logger': ( 'client/logger.html#logger',
                                                                                 'domolibrary/client/Logger.py'),
                                           'domolibrary.client.Logger.Logger.__init__': ( 'client/logger.html#logger.__init__',
                                                                                          'domolibrary/client/Logger.py'),
                                           'domolibrary.client.Logger.Logger._add_crumb': ( 'client/logger.html#logger._add_crumb',
                                                                                            'domolibrary/client/Logger.py'),
                                           'domolibrary.client.Logger.Logger._add_log': ( 'client/logger.html#logger._add_log',
                                                                                          'domolibrary/client/Logger.py'),
                                           'domolibrary.client.Logger.Logger._get_traceback': ( 'client/logger.html#logger._get_traceback',
                                                                                                'domolibrary/client/Logger.py'),
                                           'domolibrary.client.Logger.Logger._get_traceback_details': ( 'client/logger.html#logger._get_traceback_details',
                                                                                                        'domolibrary/client/Logger.py'),
                                           'domolibrary.client.Logger.Logger._remove_crumb': ( 'client/logger.html#logger._remove_crumb',
                                                                                               'domolibrary/client/Logger.py'),
                                           'domolibrary.client.Logger.Logger.log_error': ( 'client/logger.html#logger.log_error',
                                                                                           'domolibrary/client/Logger.py'),
                                           'domolibrary.client.Logger.Logger.log_info': ( 'client/logger.html#logger.log_info',
                                                                                          'domolibrary/client/Logger.py'),
                                           'domolibrary.client.Logger.Logger.log_warning': ( 'client/logger.html#logger.log_warning',
                                                                                             'domolibrary/client/Logger.py'),
                                           'domolibrary.client.Logger.Logger.output_log': ( 'client/logger.html#logger.output_log',
                                                                                            'domolibrary/client/Logger.py'),
                                           'domolibrary.client.Logger.TracebackDetails': ( 'client/logger.html#tracebackdetails',
                                                                                           'domolibrary/client/Logger.py')},
            'domolibrary.client.ResponseGetData': { 'domolibrary.client.ResponseGetData.BlockedByVPN': ( 'client/responsegetdata.html#blockedbyvpn',
                                                                                                         'domolibrary/client/ResponseGetData.py'),
                                                    'domolibrary.client.ResponseGetData.BlockedByVPN.__init__': ( 'client/responsegetdata.html#blockedbyvpn.__init__',
                                                                                                                  'domolibrary/client/ResponseGetData.py'),
                                                    'domolibrary.client.ResponseGetData.ResponseGetData': ( 'client/responsegetdata.html#responsegetdata',
                                                                                                            'domolibrary/client/ResponseGetData.py'),
                                                    'domolibrary.client.ResponseGetData.ResponseGetData._from_aiohttp_response': ( 'client/responsegetdata.html#responsegetdata._from_aiohttp_response',
                                                                                                                                   'domolibrary/client/ResponseGetData.py'),
                                                    'domolibrary.client.ResponseGetData.ResponseGetData._from_httpx_response': ( 'client/responsegetdata.html#responsegetdata._from_httpx_response',
                                                                                                                                 'domolibrary/client/ResponseGetData.py'),
                                                    'domolibrary.client.ResponseGetData.ResponseGetData._from_looper': ( 'client/responsegetdata.html#responsegetdata._from_looper',
                                                                                                                         'domolibrary/client/ResponseGetData.py'),
                                                    'domolibrary.client.ResponseGetData.ResponseGetData._from_requests_response': ( 'client/responsegetdata.html#responsegetdata._from_requests_response',
                                                                                                                                    'domolibrary/client/ResponseGetData.py'),
                                                    'domolibrary.client.ResponseGetData.ResponseGetData.set_response': ( 'client/responsegetdata.html#responsegetdata.set_response',
                                                                                                                         'domolibrary/client/ResponseGetData.py'),
                                                    'domolibrary.client.ResponseGetData._read_stream': ( 'client/responsegetdata.html#_read_stream',
                                                                                                         'domolibrary/client/ResponseGetData.py'),
                                                    'domolibrary.client.ResponseGetData._write_stream': ( 'client/responsegetdata.html#_write_stream',
                                                                                                          'domolibrary/client/ResponseGetData.py'),
                                                    'domolibrary.client.ResponseGetData.find_ip': ( 'client/responsegetdata.html#find_ip',
                                                                                                    'domolibrary/client/ResponseGetData.py')},
            'domolibrary.client.get_data': { 'domolibrary.client.get_data.GetData_Error': ( 'client/get_data.html#getdata_error',
                                                                                            'domolibrary/client/get_data.py'),
                                             'domolibrary.client.get_data.GetData_Error.__init__': ( 'client/get_data.html#getdata_error.__init__',
                                                                                                     'domolibrary/client/get_data.py'),
                                             'domolibrary.client.get_data.LooperError': ( 'client/get_data.html#loopererror',
                                                                                          'domolibrary/client/get_data.py'),
                                             'domolibrary.client.get_data.LooperError.__init__': ( 'client/get_data.html#loopererror.__init__',
                                                                                                   'domolibrary/client/get_data.py'),
                                             'domolibrary.client.get_data.get_data': ( 'client/get_data.html#get_data',
                                                                                       'domolibrary/client/get_data.py'),
                                             'domolibrary.client.get_data.get_data_aiohttp': ( 'client/get_data.html#get_data_aiohttp',
                                                                                               'domolibrary/client/get_data.py'),
                                             'domolibrary.client.get_data.looper': ( 'client/get_data.html#looper',
                                                                                     'domolibrary/client/get_data.py'),
                                             'domolibrary.client.get_data.looper_aiohttp': ( 'client/get_data.html#looper_aiohttp',
                                                                                             'domolibrary/client/get_data.py')},
            'domolibrary.integrations.Automation': { 'domolibrary.integrations.Automation.remove_partition_by_x_days': ( 'integrations/automation.html#remove_partition_by_x_days',
                                                                                                                         'domolibrary/integrations/Automation.py')},
            'domolibrary.integrations.DomoJupyter': { 'domolibrary.integrations.DomoJupyter.DomoJupyterAccount_InstanceAuth': ( 'integrations/domojupyter.html#domojupyteraccount_instanceauth',
                                                                                                                                'domolibrary/integrations/DomoJupyter.py'),
                                                      'domolibrary.integrations.DomoJupyter.DomoJupyterAccount_InstanceAuth.__post_init__': ( 'integrations/domojupyter.html#domojupyteraccount_instanceauth.__post_init__',
                                                                                                                                              'domolibrary/integrations/DomoJupyter.py'),
                                                      'domolibrary.integrations.DomoJupyter.DomoJupyterAccount_InstanceAuth._clean_account_admin_accounts': ( 'integrations/domojupyter.html#domojupyteraccount_instanceauth._clean_account_admin_accounts',
                                                                                                                                                              'domolibrary/integrations/DomoJupyter.py'),
                                                      'domolibrary.integrations.DomoJupyter.DomoJupyterAccount_InstanceAuth._generate_auth': ( 'integrations/domojupyter.html#domojupyteraccount_instanceauth._generate_auth',
                                                                                                                                               'domolibrary/integrations/DomoJupyter.py'),
                                                      'domolibrary.integrations.DomoJupyter.DomoJupyterAccount_InstanceAuth._set_display_name': ( 'integrations/domojupyter.html#domojupyteraccount_instanceauth._set_display_name',
                                                                                                                                                  'domolibrary/integrations/DomoJupyter.py'),
                                                      'domolibrary.integrations.DomoJupyter.DomoJupyterAccount_InstanceAuth._test_regex_mask': ( 'integrations/domojupyter.html#domojupyteraccount_instanceauth._test_regex_mask',
                                                                                                                                                 'domolibrary/integrations/DomoJupyter.py'),
                                                      'domolibrary.integrations.DomoJupyter.DomoJupyterAccount_InstanceAuth.generate_auth_ls': ( 'integrations/domojupyter.html#domojupyteraccount_instanceauth.generate_auth_ls',
                                                                                                                                                 'domolibrary/integrations/DomoJupyter.py'),
                                                      'domolibrary.integrations.DomoJupyter.DomoJupyterAccount_InstanceAuth.get_domo_instance_auth_account': ( 'integrations/domojupyter.html#domojupyteraccount_instanceauth.get_domo_instance_auth_account',
                                                                                                                                                               'domolibrary/integrations/DomoJupyter.py'),
                                                      'domolibrary.integrations.DomoJupyter.GenerateAuth_CredentialsNotProvided': ( 'integrations/domojupyter.html#generateauth_credentialsnotprovided',
                                                                                                                                    'domolibrary/integrations/DomoJupyter.py'),
                                                      'domolibrary.integrations.DomoJupyter.GenerateAuth_CredentialsNotProvided.__init__': ( 'integrations/domojupyter.html#generateauth_credentialsnotprovided.__init__',
                                                                                                                                             'domolibrary/integrations/DomoJupyter.py'),
                                                      'domolibrary.integrations.DomoJupyter.GenerateAuth_InvalidDomoInstanceList': ( 'integrations/domojupyter.html#generateauth_invaliddomoinstancelist',
                                                                                                                                     'domolibrary/integrations/DomoJupyter.py'),
                                                      'domolibrary.integrations.DomoJupyter.GenerateAuth_InvalidDomoInstanceList.__init__': ( 'integrations/domojupyter.html#generateauth_invaliddomoinstancelist.__init__',
                                                                                                                                              'domolibrary/integrations/DomoJupyter.py'),
                                                      'domolibrary.integrations.DomoJupyter.GetDomains_Query_AuthMatch_Error': ( 'integrations/domojupyter.html#getdomains_query_authmatch_error',
                                                                                                                                 'domolibrary/integrations/DomoJupyter.py'),
                                                      'domolibrary.integrations.DomoJupyter.GetDomains_Query_AuthMatch_Error.__init__': ( 'integrations/domojupyter.html#getdomains_query_authmatch_error.__init__',
                                                                                                                                          'domolibrary/integrations/DomoJupyter.py'),
                                                      'domolibrary.integrations.DomoJupyter.GetInstanceConfig': ( 'integrations/domojupyter.html#getinstanceconfig',
                                                                                                                  'domolibrary/integrations/DomoJupyter.py'),
                                                      'domolibrary.integrations.DomoJupyter.GetInstanceConfig.__init__': ( 'integrations/domojupyter.html#getinstanceconfig.__init__',
                                                                                                                           'domolibrary/integrations/DomoJupyter.py'),
                                                      'domolibrary.integrations.DomoJupyter.GetInstanceConfig._retrieve_company_ds': ( 'integrations/domojupyter.html#getinstanceconfig._retrieve_company_ds',
                                                                                                                                       'domolibrary/integrations/DomoJupyter.py'),
                                                      'domolibrary.integrations.DomoJupyter.GetInstanceConfig.get_domains_with_instance_auth': ( 'integrations/domojupyter.html#getinstanceconfig.get_domains_with_instance_auth',
                                                                                                                                                 'domolibrary/integrations/DomoJupyter.py'),
                                                      'domolibrary.integrations.DomoJupyter.GetJupyter_ErrorRetrievingAccount': ( 'integrations/domojupyter.html#getjupyter_errorretrievingaccount',
                                                                                                                                  'domolibrary/integrations/DomoJupyter.py'),
                                                      'domolibrary.integrations.DomoJupyter.GetJupyter_ErrorRetrievingAccount.__init__': ( 'integrations/domojupyter.html#getjupyter_errorretrievingaccount.__init__',
                                                                                                                                           'domolibrary/integrations/DomoJupyter.py'),
                                                      'domolibrary.integrations.DomoJupyter.GetJupyter_ErrorRetrievingAccountProperty': ( 'integrations/domojupyter.html#getjupyter_errorretrievingaccountproperty',
                                                                                                                                          'domolibrary/integrations/DomoJupyter.py'),
                                                      'domolibrary.integrations.DomoJupyter.GetJupyter_ErrorRetrievingAccountProperty.__init__': ( 'integrations/domojupyter.html#getjupyter_errorretrievingaccountproperty.__init__',
                                                                                                                                                   'domolibrary/integrations/DomoJupyter.py'),
                                                      'domolibrary.integrations.DomoJupyter.InvalidAccountNameError': ( 'integrations/domojupyter.html#invalidaccountnameerror',
                                                                                                                        'domolibrary/integrations/DomoJupyter.py'),
                                                      'domolibrary.integrations.DomoJupyter.InvalidAccountNameError.__init__': ( 'integrations/domojupyter.html#invalidaccountnameerror.__init__',
                                                                                                                                 'domolibrary/integrations/DomoJupyter.py'),
                                                      'domolibrary.integrations.DomoJupyter.InvalidAccountTypeError': ( 'integrations/domojupyter.html#invalidaccounttypeerror',
                                                                                                                        'domolibrary/integrations/DomoJupyter.py'),
                                                      'domolibrary.integrations.DomoJupyter.InvalidAccountTypeError.__init__': ( 'integrations/domojupyter.html#invalidaccounttypeerror.__init__',
                                                                                                                                 'domolibrary/integrations/DomoJupyter.py'),
                                                      'domolibrary.integrations.DomoJupyter.NoConfigCompanyError': ( 'integrations/domojupyter.html#noconfigcompanyerror',
                                                                                                                     'domolibrary/integrations/DomoJupyter.py'),
                                                      'domolibrary.integrations.DomoJupyter.NoConfigCompanyError.__init__': ( 'integrations/domojupyter.html#noconfigcompanyerror.__init__',
                                                                                                                              'domolibrary/integrations/DomoJupyter.py'),
                                                      'domolibrary.integrations.DomoJupyter.get_jupyter_account': ( 'integrations/domojupyter.html#get_jupyter_account',
                                                                                                                    'domolibrary/integrations/DomoJupyter.py')},
            'domolibrary.integrations.MonitDataset': { 'domolibrary.integrations.MonitDataset.MonitDataset_Data': ( 'integrations/monitdataset.html#monitdataset_data',
                                                                                                                    'domolibrary/integrations/MonitDataset.py'),
                                                       'domolibrary.integrations.MonitDataset.MonitDataset_Record': ( 'integrations/monitdataset.html#monitdataset_record',
                                                                                                                      'domolibrary/integrations/MonitDataset.py')},
            'domolibrary.integrations.RoleHierarchy': { 'domolibrary.integrations.RoleHierarchy.calc_role': ( 'integrations/rolehierarchy.html#calc_role',
                                                                                                              'domolibrary/integrations/RoleHierarchy.py'),
                                                        'domolibrary.integrations.RoleHierarchy.extract_role_hierarchy': ( 'integrations/rolehierarchy.html#extract_role_hierarchy',
                                                                                                                           'domolibrary/integrations/RoleHierarchy.py'),
                                                        'domolibrary.integrations.RoleHierarchy.get_roles_w_hierarchy': ( 'integrations/rolehierarchy.html#get_roles_w_hierarchy',
                                                                                                                          'domolibrary/integrations/RoleHierarchy.py')},
            'domolibrary.routes.account': { 'domolibrary.routes.account.AccountConfig_InvalidDataProvider': ( 'routes/account.html#accountconfig_invaliddataprovider',
                                                                                                              'domolibrary/routes/account.py'),
                                            'domolibrary.routes.account.AccountConfig_InvalidDataProvider.__init__': ( 'routes/account.html#accountconfig_invaliddataprovider.__init__',
                                                                                                                       'domolibrary/routes/account.py'),
                                            'domolibrary.routes.account.GetAccount_NoMatch': ( 'routes/account.html#getaccount_nomatch',
                                                                                               'domolibrary/routes/account.py'),
                                            'domolibrary.routes.account.GetAccount_NoMatch.__init__': ( 'routes/account.html#getaccount_nomatch.__init__',
                                                                                                        'domolibrary/routes/account.py'),
                                            'domolibrary.routes.account.ShareAccount': ( 'routes/account.html#shareaccount',
                                                                                         'domolibrary/routes/account.py'),
                                            'domolibrary.routes.account.ShareAccount_V1_AccessLevel': ( 'routes/account.html#shareaccount_v1_accesslevel',
                                                                                                        'domolibrary/routes/account.py'),
                                            'domolibrary.routes.account.ShareAccount_V2_AccessLevel': ( 'routes/account.html#shareaccount_v2_accesslevel',
                                                                                                        'domolibrary/routes/account.py'),
                                            'domolibrary.routes.account.create_account': ( 'routes/account.html#create_account',
                                                                                           'domolibrary/routes/account.py'),
                                            'domolibrary.routes.account.delete_account': ( 'routes/account.html#delete_account',
                                                                                           'domolibrary/routes/account.py'),
                                            'domolibrary.routes.account.generate_share_account_payload_v1': ( 'routes/account.html#generate_share_account_payload_v1',
                                                                                                              'domolibrary/routes/account.py'),
                                            'domolibrary.routes.account.generate_share_account_payload_v2': ( 'routes/account.html#generate_share_account_payload_v2',
                                                                                                              'domolibrary/routes/account.py'),
                                            'domolibrary.routes.account.get_account_config': ( 'routes/account.html#get_account_config',
                                                                                               'domolibrary/routes/account.py'),
                                            'domolibrary.routes.account.get_account_from_id': ( 'routes/account.html#get_account_from_id',
                                                                                                'domolibrary/routes/account.py'),
                                            'domolibrary.routes.account.get_accounts': ( 'routes/account.html#get_accounts',
                                                                                         'domolibrary/routes/account.py'),
                                            'domolibrary.routes.account.share_account_v1': ( 'routes/account.html#share_account_v1',
                                                                                             'domolibrary/routes/account.py'),
                                            'domolibrary.routes.account.share_account_v2': ( 'routes/account.html#share_account_v2',
                                                                                             'domolibrary/routes/account.py'),
                                            'domolibrary.routes.account.update_account_config': ( 'routes/account.html#update_account_config',
                                                                                                  'domolibrary/routes/account.py'),
                                            'domolibrary.routes.account.update_account_name': ( 'routes/account.html#update_account_name',
                                                                                                'domolibrary/routes/account.py')},
            'domolibrary.routes.activity_log': { 'domolibrary.routes.activity_log.get_activity_log_object_types': ( 'routes/activity_log.html#get_activity_log_object_types',
                                                                                                                    'domolibrary/routes/activity_log.py'),
                                                 'domolibrary.routes.activity_log.search_activity_log': ( 'routes/activity_log.html#search_activity_log',
                                                                                                          'domolibrary/routes/activity_log.py')},
            'domolibrary.routes.application': { 'domolibrary.routes.application.get_application_by_id': ( 'routes/application.html#get_application_by_id',
                                                                                                          'domolibrary/routes/application.py'),
                                                'domolibrary.routes.application.get_applications': ( 'routes/application.html#get_applications',
                                                                                                     'domolibrary/routes/application.py')},
            'domolibrary.routes.bootstrap': { 'domolibrary.routes.bootstrap.get_bootstrap': ( 'routes/bootstrap.html#get_bootstrap',
                                                                                              'domolibrary/routes/bootstrap.py'),
                                              'domolibrary.routes.bootstrap.get_bootstrap_features': ( 'routes/bootstrap.html#get_bootstrap_features',
                                                                                                       'domolibrary/routes/bootstrap.py'),
                                              'domolibrary.routes.bootstrap.get_bootstrap_pages': ( 'routes/bootstrap.html#get_bootstrap_pages',
                                                                                                    'domolibrary/routes/bootstrap.py')},
            'domolibrary.routes.card': { 'domolibrary.routes.card.CardSearch_NotFoundError': ( 'routes/card.html#cardsearch_notfounderror',
                                                                                               'domolibrary/routes/card.py'),
                                         'domolibrary.routes.card.CardSearch_NotFoundError.__init__': ( 'routes/card.html#cardsearch_notfounderror.__init__',
                                                                                                        'domolibrary/routes/card.py'),
                                         'domolibrary.routes.card.generate_body_search_cards_admin_summary': ( 'routes/card.html#generate_body_search_cards_admin_summary',
                                                                                                               'domolibrary/routes/card.py'),
                                         'domolibrary.routes.card.get_card_metadata': ( 'routes/card.html#get_card_metadata',
                                                                                        'domolibrary/routes/card.py'),
                                         'domolibrary.routes.card.get_kpi_definition': ( 'routes/card.html#get_kpi_definition',
                                                                                         'domolibrary/routes/card.py'),
                                         'domolibrary.routes.card.search_cards_admin_summary': ( 'routes/card.html#search_cards_admin_summary',
                                                                                                 'domolibrary/routes/card.py')},
            'domolibrary.routes.datacenter': { 'domolibrary.routes.datacenter.Datacenter_Enum': ( 'routes/datacenter.html#datacenter_enum',
                                                                                                  'domolibrary/routes/datacenter.py'),
                                               'domolibrary.routes.datacenter.Datacenter_Filter_Field_Certification_Enum': ( 'routes/datacenter.html#datacenter_filter_field_certification_enum',
                                                                                                                             'domolibrary/routes/datacenter.py'),
                                               'domolibrary.routes.datacenter.Datacenter_Filter_Field_Enum': ( 'routes/datacenter.html#datacenter_filter_field_enum',
                                                                                                               'domolibrary/routes/datacenter.py'),
                                               'domolibrary.routes.datacenter.Dataflow_Type_Filter_Enum': ( 'routes/datacenter.html#dataflow_type_filter_enum',
                                                                                                            'domolibrary/routes/datacenter.py'),
                                               'domolibrary.routes.datacenter.SearchDatacenter_NoResultsFound': ( 'routes/datacenter.html#searchdatacenter_noresultsfound',
                                                                                                                  'domolibrary/routes/datacenter.py'),
                                               'domolibrary.routes.datacenter.SearchDatacenter_NoResultsFound.__init__': ( 'routes/datacenter.html#searchdatacenter_noresultsfound.__init__',
                                                                                                                           'domolibrary/routes/datacenter.py'),
                                               'domolibrary.routes.datacenter.ShareResource_Enum': ( 'routes/datacenter.html#shareresource_enum',
                                                                                                     'domolibrary/routes/datacenter.py'),
                                               'domolibrary.routes.datacenter.generate_search_datacenter_account_body': ( 'routes/datacenter.html#generate_search_datacenter_account_body',
                                                                                                                          'domolibrary/routes/datacenter.py'),
                                               'domolibrary.routes.datacenter.generate_search_datacenter_body': ( 'routes/datacenter.html#generate_search_datacenter_body',
                                                                                                                  'domolibrary/routes/datacenter.py'),
                                               'domolibrary.routes.datacenter.generate_search_datacenter_filter': ( 'routes/datacenter.html#generate_search_datacenter_filter',
                                                                                                                    'domolibrary/routes/datacenter.py'),
                                               'domolibrary.routes.datacenter.generate_search_datacenter_filter_search_term': ( 'routes/datacenter.html#generate_search_datacenter_filter_search_term',
                                                                                                                                'domolibrary/routes/datacenter.py'),
                                               'domolibrary.routes.datacenter.get_lineage_upstream': ( 'routes/datacenter.html#get_lineage_upstream',
                                                                                                       'domolibrary/routes/datacenter.py'),
                                               'domolibrary.routes.datacenter.search_datacenter': ( 'routes/datacenter.html#search_datacenter',
                                                                                                    'domolibrary/routes/datacenter.py'),
                                               'domolibrary.routes.datacenter.share_resource': ( 'routes/datacenter.html#share_resource',
                                                                                                 'domolibrary/routes/datacenter.py')},
            'domolibrary.routes.dataflow': { 'domolibrary.routes.dataflow.execute_dataflow': ( 'routes/dataflow.html#execute_dataflow',
                                                                                               'domolibrary/routes/dataflow.py'),
                                             'domolibrary.routes.dataflow.get_dataflow_by_id': ( 'routes/dataflow.html#get_dataflow_by_id',
                                                                                                 'domolibrary/routes/dataflow.py')},
            'domolibrary.routes.dataset': { 'domolibrary.routes.dataset.DatasetNotFoundError': ( 'routes/dataset.html#datasetnotfounderror',
                                                                                                 'domolibrary/routes/dataset.py'),
                                            'domolibrary.routes.dataset.DatasetNotFoundError.__init__': ( 'routes/dataset.html#datasetnotfounderror.__init__',
                                                                                                          'domolibrary/routes/dataset.py'),
                                            'domolibrary.routes.dataset.QueryRequestError': ( 'routes/dataset.html#queryrequesterror',
                                                                                              'domolibrary/routes/dataset.py'),
                                            'domolibrary.routes.dataset.QueryRequestError.__init__': ( 'routes/dataset.html#queryrequesterror.__init__',
                                                                                                       'domolibrary/routes/dataset.py'),
                                            'domolibrary.routes.dataset.ShareDataset_AccessLevelEnum': ( 'routes/dataset.html#sharedataset_accesslevelenum',
                                                                                                         'domolibrary/routes/dataset.py'),
                                            'domolibrary.routes.dataset.ShareDataset_Error': ( 'routes/dataset.html#sharedataset_error',
                                                                                               'domolibrary/routes/dataset.py'),
                                            'domolibrary.routes.dataset.ShareDataset_Error.__init__': ( 'routes/dataset.html#sharedataset_error.__init__',
                                                                                                        'domolibrary/routes/dataset.py'),
                                            'domolibrary.routes.dataset.UploadDataError': ( 'routes/dataset.html#uploaddataerror',
                                                                                            'domolibrary/routes/dataset.py'),
                                            'domolibrary.routes.dataset.UploadDataError.__init__': ( 'routes/dataset.html#uploaddataerror.__init__',
                                                                                                     'domolibrary/routes/dataset.py'),
                                            'domolibrary.routes.dataset.alter_schema': ( 'routes/dataset.html#alter_schema',
                                                                                         'domolibrary/routes/dataset.py'),
                                            'domolibrary.routes.dataset.create': ( 'routes/dataset.html#create',
                                                                                   'domolibrary/routes/dataset.py'),
                                            'domolibrary.routes.dataset.delete': ( 'routes/dataset.html#delete',
                                                                                   'domolibrary/routes/dataset.py'),
                                            'domolibrary.routes.dataset.delete_partition_stage_1': ( 'routes/dataset.html#delete_partition_stage_1',
                                                                                                     'domolibrary/routes/dataset.py'),
                                            'domolibrary.routes.dataset.delete_partition_stage_2': ( 'routes/dataset.html#delete_partition_stage_2',
                                                                                                     'domolibrary/routes/dataset.py'),
                                            'domolibrary.routes.dataset.generate_create_dataset_body': ( 'routes/dataset.html#generate_create_dataset_body',
                                                                                                         'domolibrary/routes/dataset.py'),
                                            'domolibrary.routes.dataset.generate_list_partitions_body': ( 'routes/dataset.html#generate_list_partitions_body',
                                                                                                          'domolibrary/routes/dataset.py'),
                                            'domolibrary.routes.dataset.generate_share_dataset_payload': ( 'routes/dataset.html#generate_share_dataset_payload',
                                                                                                           'domolibrary/routes/dataset.py'),
                                            'domolibrary.routes.dataset.get_dataset_by_id': ( 'routes/dataset.html#get_dataset_by_id',
                                                                                              'domolibrary/routes/dataset.py'),
                                            'domolibrary.routes.dataset.get_schema': ( 'routes/dataset.html#get_schema',
                                                                                       'domolibrary/routes/dataset.py'),
                                            'domolibrary.routes.dataset.index_dataset': ( 'routes/dataset.html#index_dataset',
                                                                                          'domolibrary/routes/dataset.py'),
                                            'domolibrary.routes.dataset.index_status': ( 'routes/dataset.html#index_status',
                                                                                         'domolibrary/routes/dataset.py'),
                                            'domolibrary.routes.dataset.list_partitions': ( 'routes/dataset.html#list_partitions',
                                                                                            'domolibrary/routes/dataset.py'),
                                            'domolibrary.routes.dataset.query_dataset_private': ( 'routes/dataset.html#query_dataset_private',
                                                                                                  'domolibrary/routes/dataset.py'),
                                            'domolibrary.routes.dataset.query_dataset_public': ( 'routes/dataset.html#query_dataset_public',
                                                                                                 'domolibrary/routes/dataset.py'),
                                            'domolibrary.routes.dataset.set_dataset_tags': ( 'routes/dataset.html#set_dataset_tags',
                                                                                             'domolibrary/routes/dataset.py'),
                                            'domolibrary.routes.dataset.share_dataset': ( 'routes/dataset.html#share_dataset',
                                                                                          'domolibrary/routes/dataset.py'),
                                            'domolibrary.routes.dataset.upload_dataset_stage_1': ( 'routes/dataset.html#upload_dataset_stage_1',
                                                                                                   'domolibrary/routes/dataset.py'),
                                            'domolibrary.routes.dataset.upload_dataset_stage_2_df': ( 'routes/dataset.html#upload_dataset_stage_2_df',
                                                                                                      'domolibrary/routes/dataset.py'),
                                            'domolibrary.routes.dataset.upload_dataset_stage_2_file': ( 'routes/dataset.html#upload_dataset_stage_2_file',
                                                                                                        'domolibrary/routes/dataset.py'),
                                            'domolibrary.routes.dataset.upload_dataset_stage_3': ( 'routes/dataset.html#upload_dataset_stage_3',
                                                                                                   'domolibrary/routes/dataset.py')},
            'domolibrary.routes.grant': { 'domolibrary.routes.grant.GetGrants_Error': ( 'routes/grant.html#getgrants_error',
                                                                                        'domolibrary/routes/grant.py'),
                                          'domolibrary.routes.grant.GetGrants_Error.__init__': ( 'routes/grant.html#getgrants_error.__init__',
                                                                                                 'domolibrary/routes/grant.py'),
                                          'domolibrary.routes.grant.get_grants': ( 'routes/grant.html#get_grants',
                                                                                   'domolibrary/routes/grant.py')},
            'domolibrary.routes.group': { 'domolibrary.routes.group.CreateGroup_Error': ( 'routes/group.html#creategroup_error',
                                                                                          'domolibrary/routes/group.py'),
                                          'domolibrary.routes.group.CreateGroup_Error.__init__': ( 'routes/group.html#creategroup_error.__init__',
                                                                                                   'domolibrary/routes/group.py'),
                                          'domolibrary.routes.group.GroupType_Enum': ( 'routes/group.html#grouptype_enum',
                                                                                       'domolibrary/routes/group.py'),
                                          'domolibrary.routes.group.SearchGroups_Error': ( 'routes/group.html#searchgroups_error',
                                                                                           'domolibrary/routes/group.py'),
                                          'domolibrary.routes.group.SearchGroups_Error.__init__': ( 'routes/group.html#searchgroups_error.__init__',
                                                                                                    'domolibrary/routes/group.py'),
                                          'domolibrary.routes.group.create_group': ( 'routes/group.html#create_group',
                                                                                     'domolibrary/routes/group.py'),
                                          'domolibrary.routes.group.generate_body_create_group': ( 'routes/group.html#generate_body_create_group',
                                                                                                   'domolibrary/routes/group.py'),
                                          'domolibrary.routes.group.generate_body_update_group_membership': ( 'routes/group.html#generate_body_update_group_membership',
                                                                                                              'domolibrary/routes/group.py'),
                                          'domolibrary.routes.group.generate_body_update_group_membership_entity': ( 'routes/group.html#generate_body_update_group_membership_entity',
                                                                                                                     'domolibrary/routes/group.py'),
                                          'domolibrary.routes.group.get_all_groups': ( 'routes/group.html#get_all_groups',
                                                                                       'domolibrary/routes/group.py'),
                                          'domolibrary.routes.group.get_group_by_id': ( 'routes/group.html#get_group_by_id',
                                                                                        'domolibrary/routes/group.py'),
                                          'domolibrary.routes.group.get_group_membership': ( 'routes/group.html#get_group_membership',
                                                                                             'domolibrary/routes/group.py'),
                                          'domolibrary.routes.group.get_group_owners': ( 'routes/group.html#get_group_owners',
                                                                                         'domolibrary/routes/group.py'),
                                          'domolibrary.routes.group.search_groups_by_name': ( 'routes/group.html#search_groups_by_name',
                                                                                              'domolibrary/routes/group.py'),
                                          'domolibrary.routes.group.update_group': ( 'routes/group.html#update_group',
                                                                                     'domolibrary/routes/group.py'),
                                          'domolibrary.routes.group.update_group_membership': ( 'routes/group.html#update_group_membership',
                                                                                                'domolibrary/routes/group.py')},
            'domolibrary.routes.instance_config': { 'domolibrary.routes.instance_config.Allowlist_UnableToUpdate': ( 'routes/instance_config.html#allowlist_unabletoupdate',
                                                                                                                     'domolibrary/routes/instance_config.py'),
                                                    'domolibrary.routes.instance_config.Allowlist_UnableToUpdate.__init__': ( 'routes/instance_config.html#allowlist_unabletoupdate.__init__',
                                                                                                                              'domolibrary/routes/instance_config.py'),
                                                    'domolibrary.routes.instance_config.GetDomains_NotFound': ( 'routes/instance_config.html#getdomains_notfound',
                                                                                                                'domolibrary/routes/instance_config.py'),
                                                    'domolibrary.routes.instance_config.GetDomains_NotFound.__init__': ( 'routes/instance_config.html#getdomains_notfound.__init__',
                                                                                                                         'domolibrary/routes/instance_config.py'),
                                                    'domolibrary.routes.instance_config.get_allowlist': ( 'routes/instance_config.html#get_allowlist',
                                                                                                          'domolibrary/routes/instance_config.py'),
                                                    'domolibrary.routes.instance_config.get_authorized_domains': ( 'routes/instance_config.html#get_authorized_domains',
                                                                                                                   'domolibrary/routes/instance_config.py'),
                                                    'domolibrary.routes.instance_config.set_allowlist': ( 'routes/instance_config.html#set_allowlist',
                                                                                                          'domolibrary/routes/instance_config.py'),
                                                    'domolibrary.routes.instance_config.set_authorized_domains': ( 'routes/instance_config.html#set_authorized_domains',
                                                                                                                   'domolibrary/routes/instance_config.py')},
            'domolibrary.routes.job': { 'domolibrary.routes.job.add_job': ('routes/job.html#add_job', 'domolibrary/routes/job.py'),
                                        'domolibrary.routes.job.generate_body_remote_domostats': ( 'routes/job.html#generate_body_remote_domostats',
                                                                                                   'domolibrary/routes/job.py'),
                                        'domolibrary.routes.job.generate_body_watchdog_generic': ( 'routes/job.html#generate_body_watchdog_generic',
                                                                                                   'domolibrary/routes/job.py'),
                                        'domolibrary.routes.job.get_jobs': ('routes/job.html#get_jobs', 'domolibrary/routes/job.py'),
                                        'domolibrary.routes.job.update_job': ('routes/job.html#update_job', 'domolibrary/routes/job.py'),
                                        'domolibrary.routes.job.update_job_trigger': ( 'routes/job.html#update_job_trigger',
                                                                                       'domolibrary/routes/job.py')},
            'domolibrary.routes.page': { 'domolibrary.routes.page.delete_writelock': ( 'routes/page.html#delete_writelock',
                                                                                       'domolibrary/routes/page.py'),
                                         'domolibrary.routes.page.get_page_access_list': ( 'routes/page.html#get_page_access_list',
                                                                                           'domolibrary/routes/page.py'),
                                         'domolibrary.routes.page.get_page_by_id': ( 'routes/page.html#get_page_by_id',
                                                                                     'domolibrary/routes/page.py'),
                                         'domolibrary.routes.page.get_page_definition': ( 'routes/page.html#get_page_definition',
                                                                                          'domolibrary/routes/page.py'),
                                         'domolibrary.routes.page.get_pages_adminsummary': ( 'routes/page.html#get_pages_adminsummary',
                                                                                             'domolibrary/routes/page.py'),
                                         'domolibrary.routes.page.put_writelock': ( 'routes/page.html#put_writelock',
                                                                                    'domolibrary/routes/page.py'),
                                         'domolibrary.routes.page.update_page_layout': ( 'routes/page.html#update_page_layout',
                                                                                         'domolibrary/routes/page.py')},
            'domolibrary.routes.pdp': { 'domolibrary.routes.pdp.CreatePolicy_Error': ( 'routes/pdp.html#createpolicy_error',
                                                                                       'domolibrary/routes/pdp.py'),
                                        'domolibrary.routes.pdp.CreatePolicy_Error.__init__': ( 'routes/pdp.html#createpolicy_error.__init__',
                                                                                                'domolibrary/routes/pdp.py'),
                                        'domolibrary.routes.pdp.PDP_NotRetrieved': ( 'routes/pdp.html#pdp_notretrieved',
                                                                                     'domolibrary/routes/pdp.py'),
                                        'domolibrary.routes.pdp.PDP_NotRetrieved.__init__': ( 'routes/pdp.html#pdp_notretrieved.__init__',
                                                                                              'domolibrary/routes/pdp.py'),
                                        'domolibrary.routes.pdp.create_policy': ( 'routes/pdp.html#create_policy',
                                                                                  'domolibrary/routes/pdp.py'),
                                        'domolibrary.routes.pdp.delete_policy': ( 'routes/pdp.html#delete_policy',
                                                                                  'domolibrary/routes/pdp.py'),
                                        'domolibrary.routes.pdp.generate_policy_body': ( 'routes/pdp.html#generate_policy_body',
                                                                                         'domolibrary/routes/pdp.py'),
                                        'domolibrary.routes.pdp.generate_policy_parameter_simple': ( 'routes/pdp.html#generate_policy_parameter_simple',
                                                                                                     'domolibrary/routes/pdp.py'),
                                        'domolibrary.routes.pdp.get_pdp_policies': ( 'routes/pdp.html#get_pdp_policies',
                                                                                     'domolibrary/routes/pdp.py'),
                                        'domolibrary.routes.pdp.toggle_pdp': ('routes/pdp.html#toggle_pdp', 'domolibrary/routes/pdp.py'),
                                        'domolibrary.routes.pdp.update_policy': ( 'routes/pdp.html#update_policy',
                                                                                  'domolibrary/routes/pdp.py')},
            'domolibrary.routes.publish': { 'domolibrary.routes.publish.accept_invite_by_id': ( 'routes/publish.html#accept_invite_by_id',
                                                                                                'domolibrary/routes/publish.py'),
                                            'domolibrary.routes.publish.create_publish_job': ( 'routes/publish.html#create_publish_job',
                                                                                               'domolibrary/routes/publish.py'),
                                            'domolibrary.routes.publish.generate_publish_body': ( 'routes/publish.html#generate_publish_body',
                                                                                                  'domolibrary/routes/publish.py'),
                                            'domolibrary.routes.publish.get_publication_by_id': ( 'routes/publish.html#get_publication_by_id',
                                                                                                  'domolibrary/routes/publish.py'),
                                            'domolibrary.routes.publish.get_subscription_invititations': ( 'routes/publish.html#get_subscription_invititations',
                                                                                                           'domolibrary/routes/publish.py'),
                                            'domolibrary.routes.publish.get_subscription_summaries': ( 'routes/publish.html#get_subscription_summaries',
                                                                                                       'domolibrary/routes/publish.py'),
                                            'domolibrary.routes.publish.refresh_publish_jobs': ( 'routes/publish.html#refresh_publish_jobs',
                                                                                                 'domolibrary/routes/publish.py'),
                                            'domolibrary.routes.publish.search_publications': ( 'routes/publish.html#search_publications',
                                                                                                'domolibrary/routes/publish.py'),
                                            'domolibrary.routes.publish.udpate_publish_job': ( 'routes/publish.html#udpate_publish_job',
                                                                                               'domolibrary/routes/publish.py')},
            'domolibrary.routes.role': { 'domolibrary.routes.role.Role_NotRetrieved': ( 'routes/role.html#role_notretrieved',
                                                                                        'domolibrary/routes/role.py'),
                                         'domolibrary.routes.role.Role_NotRetrieved.__init__': ( 'routes/role.html#role_notretrieved.__init__',
                                                                                                 'domolibrary/routes/role.py'),
                                         'domolibrary.routes.role.create_role': ( 'routes/role.html#create_role',
                                                                                  'domolibrary/routes/role.py'),
                                         'domolibrary.routes.role.delete_role': ( 'routes/role.html#delete_role',
                                                                                  'domolibrary/routes/role.py'),
                                         'domolibrary.routes.role.get_default_role': ( 'routes/role.html#get_default_role',
                                                                                       'domolibrary/routes/role.py'),
                                         'domolibrary.routes.role.get_role_grants': ( 'routes/role.html#get_role_grants',
                                                                                      'domolibrary/routes/role.py'),
                                         'domolibrary.routes.role.get_role_membership': ( 'routes/role.html#get_role_membership',
                                                                                          'domolibrary/routes/role.py'),
                                         'domolibrary.routes.role.get_roles': ('routes/role.html#get_roles', 'domolibrary/routes/role.py'),
                                         'domolibrary.routes.role.role_membership_add_users': ( 'routes/role.html#role_membership_add_users',
                                                                                                'domolibrary/routes/role.py'),
                                         'domolibrary.routes.role.set_default_role': ( 'routes/role.html#set_default_role',
                                                                                       'domolibrary/routes/role.py'),
                                         'domolibrary.routes.role.set_role_grants': ( 'routes/role.html#set_role_grants',
                                                                                      'domolibrary/routes/role.py'),
                                         'domolibrary.routes.role.update_role_metadata': ( 'routes/role.html#update_role_metadata',
                                                                                           'domolibrary/routes/role.py')},
            'domolibrary.routes.sandbox': { 'domolibrary.routes.sandbox.get_repo_from_id': ( 'routes/sandbox.html#get_repo_from_id',
                                                                                             'domolibrary/routes/sandbox.py'),
                                            'domolibrary.routes.sandbox.get_shared_repos': ( 'routes/sandbox.html#get_shared_repos',
                                                                                             'domolibrary/routes/sandbox.py')},
            'domolibrary.routes.stream': { 'domolibrary.routes.stream.create_stream': ( 'routes/stream.html#create_stream',
                                                                                        'domolibrary/routes/stream.py'),
                                           'domolibrary.routes.stream.execute_stream': ( 'routes/stream.html#execute_stream',
                                                                                         'domolibrary/routes/stream.py'),
                                           'domolibrary.routes.stream.get_stream_by_id': ( 'routes/stream.html#get_stream_by_id',
                                                                                           'domolibrary/routes/stream.py'),
                                           'domolibrary.routes.stream.update_stream': ( 'routes/stream.html#update_stream',
                                                                                        'domolibrary/routes/stream.py')},
            'domolibrary.routes.user': { 'domolibrary.routes.user.ResetPassword_PasswordUsed': ( 'routes/user.html#resetpassword_passwordused',
                                                                                                 'domolibrary/routes/user.py'),
                                         'domolibrary.routes.user.ResetPassword_PasswordUsed.__init__': ( 'routes/user.html#resetpassword_passwordused.__init__',
                                                                                                          'domolibrary/routes/user.py'),
                                         'domolibrary.routes.user.SearchUser_NoResults': ( 'routes/user.html#searchuser_noresults',
                                                                                           'domolibrary/routes/user.py'),
                                         'domolibrary.routes.user.SearchUser_NoResults.__init__': ( 'routes/user.html#searchuser_noresults.__init__',
                                                                                                    'domolibrary/routes/user.py'),
                                         'domolibrary.routes.user.UserProperty': ( 'routes/user.html#userproperty',
                                                                                   'domolibrary/routes/user.py'),
                                         'domolibrary.routes.user.UserProperty.__init__': ( 'routes/user.html#userproperty.__init__',
                                                                                            'domolibrary/routes/user.py'),
                                         'domolibrary.routes.user.UserProperty._valid_value': ( 'routes/user.html#userproperty._valid_value',
                                                                                                'domolibrary/routes/user.py'),
                                         'domolibrary.routes.user.UserProperty.to_json': ( 'routes/user.html#userproperty.to_json',
                                                                                           'domolibrary/routes/user.py'),
                                         'domolibrary.routes.user.UserProperty_Type': ( 'routes/user.html#userproperty_type',
                                                                                        'domolibrary/routes/user.py'),
                                         'domolibrary.routes.user.create_user': ( 'routes/user.html#create_user',
                                                                                  'domolibrary/routes/user.py'),
                                         'domolibrary.routes.user.generate_patch_user_property_body': ( 'routes/user.html#generate_patch_user_property_body',
                                                                                                        'domolibrary/routes/user.py'),
                                         'domolibrary.routes.user.generate_search_users_body_by_email': ( 'routes/user.html#generate_search_users_body_by_email',
                                                                                                          'domolibrary/routes/user.py'),
                                         'domolibrary.routes.user.generate_search_users_body_by_id': ( 'routes/user.html#generate_search_users_body_by_id',
                                                                                                       'domolibrary/routes/user.py'),
                                         'domolibrary.routes.user.get_all_users': ( 'routes/user.html#get_all_users',
                                                                                    'domolibrary/routes/user.py'),
                                         'domolibrary.routes.user.get_by_id': ('routes/user.html#get_by_id', 'domolibrary/routes/user.py'),
                                         'domolibrary.routes.user.process_v1_search_users': ( 'routes/user.html#process_v1_search_users',
                                                                                              'domolibrary/routes/user.py'),
                                         'domolibrary.routes.user.request_password_reset': ( 'routes/user.html#request_password_reset',
                                                                                             'domolibrary/routes/user.py'),
                                         'domolibrary.routes.user.reset_password': ( 'routes/user.html#reset_password',
                                                                                     'domolibrary/routes/user.py'),
                                         'domolibrary.routes.user.search_users': ( 'routes/user.html#search_users',
                                                                                   'domolibrary/routes/user.py'),
                                         'domolibrary.routes.user.search_virtual_user_by_subscriber_instance': ( 'routes/user.html#search_virtual_user_by_subscriber_instance',
                                                                                                                 'domolibrary/routes/user.py'),
                                         'domolibrary.routes.user.set_user_landing_page': ( 'routes/user.html#set_user_landing_page',
                                                                                            'domolibrary/routes/user.py'),
                                         'domolibrary.routes.user.update_user': ( 'routes/user.html#update_user',
                                                                                  'domolibrary/routes/user.py')},
            'domolibrary.utils.DictDot': { 'domolibrary.utils.DictDot.DictDot': ( 'utils/dictdot.html#dictdot',
                                                                                  'domolibrary/utils/DictDot.py'),
                                           'domolibrary.utils.DictDot.DictDot.__getattr__': ( 'utils/dictdot.html#dictdot.__getattr__',
                                                                                              'domolibrary/utils/DictDot.py'),
                                           'domolibrary.utils.DictDot.DictDot.__init__': ( 'utils/dictdot.html#dictdot.__init__',
                                                                                           'domolibrary/utils/DictDot.py'),
                                           'domolibrary.utils.DictDot.split_str_to_obj': ( 'utils/dictdot.html#split_str_to_obj',
                                                                                           'domolibrary/utils/DictDot.py')},
            'domolibrary.utils.chunk_execution': { 'domolibrary.utils.chunk_execution.chunk_list': ( 'utils/chunk_execution.html#chunk_list',
                                                                                                     'domolibrary/utils/chunk_execution.py'),
                                                   'domolibrary.utils.chunk_execution.run_sequence': ( 'utils/chunk_execution.html#run_sequence',
                                                                                                       'domolibrary/utils/chunk_execution.py')},
            'domolibrary.utils.convert': { 'domolibrary.utils.convert.ConcatDataframe_InvalidElement': ( 'utils/convert.html#concatdataframe_invalidelement',
                                                                                                         'domolibrary/utils/convert.py'),
                                           'domolibrary.utils.convert.ConcatDataframe_InvalidElement.__init__': ( 'utils/convert.html#concatdataframe_invalidelement.__init__',
                                                                                                                  'domolibrary/utils/convert.py'),
                                           'domolibrary.utils.convert.concat_list_dataframe': ( 'utils/convert.html#concat_list_dataframe',
                                                                                                'domolibrary/utils/convert.py'),
                                           'domolibrary.utils.convert.convert_datetime_to_epoch_millisecond': ( 'utils/convert.html#convert_datetime_to_epoch_millisecond',
                                                                                                                'domolibrary/utils/convert.py'),
                                           'domolibrary.utils.convert.convert_epoch_millisecond_to_datetime': ( 'utils/convert.html#convert_epoch_millisecond_to_datetime',
                                                                                                                'domolibrary/utils/convert.py'),
                                           'domolibrary.utils.convert.convert_snake_to_pascal': ( 'utils/convert.html#convert_snake_to_pascal',
                                                                                                  'domolibrary/utils/convert.py')},
            'domolibrary.utils.read_creds_from_dotenv': { 'domolibrary.utils.read_creds_from_dotenv.ReadCreds_EnvFileNotExist': ( 'utils/read_creds_from_dotenv.html#readcreds_envfilenotexist',
                                                                                                                                  'domolibrary/utils/read_creds_from_dotenv.py'),
                                                          'domolibrary.utils.read_creds_from_dotenv.ReadCreds_EnvFileNotExist.__init__': ( 'utils/read_creds_from_dotenv.html#readcreds_envfilenotexist.__init__',
                                                                                                                                           'domolibrary/utils/read_creds_from_dotenv.py'),
                                                          'domolibrary.utils.read_creds_from_dotenv.read_creds_from_dotenv': ( 'utils/read_creds_from_dotenv.html#read_creds_from_dotenv',
                                                                                                                               'domolibrary/utils/read_creds_from_dotenv.py')},
            'domolibrary.utils.upload_data': { 'domolibrary.utils.upload_data.loop_upload': ( 'utils/upload_data.html#loop_upload',
                                                                                              'domolibrary/utils/upload_data.py'),
                                               'domolibrary.utils.upload_data.upload_data': ( 'utils/upload_data.html#upload_data',
                                                                                              'domolibrary/utils/upload_data.py')}}}



import aiohttp

from dataclasses import dataclass, field
from typing import List

from .DomoAuth import DomoFullAuth
from .routes import group_routes
from ..utils.Base import Base
from ..utils.DictDot import DictDot


class GroupMembership:
    def __init__(self, group):
        self.group = group
        self.group_members_ids = self.set_group_member_ids()

    def set_group_member_ids(self):
        return [member.id for member in self.group.group_members]

    async def _update_group_access(self, full_auth: DomoFullAuth, body,
                                   log_results: bool = False, debug: bool = False):

        res = await group_routes.update_group_membership(full_auth=full_auth, body=body,
                                                         log_results=log_results,
                                                         debug=debug)

        if debug:
            res.print(is_pretty=True)

        if res.status == 200:
            if log_results:
                if self.group_members:
                    print(
                        f'Group Membership includes {len(self.group_members)}')

        return res

    async def set_membership(self, user_ids_list,
                             full_auth: DomoFullAuth = None,
                             log_results: bool = False, debug: bool = False):

        full_auth = full_auth or self.group.full_auth

        add_user_arr = [str(uid) for uid in user_ids_list]
        remove_user_arr = [
            str(uid) for uid in self.group_members_ids if str(uid) not in add_user_arr]

        body = group_routes.generate_body_update_group_membership(group_id=self.group.id,
                                                                  add_user_arr=add_user_arr,
                                                                  remove_user_arr=remove_user_arr)

        return await self._update_group_access(full_auth=full_auth, body=body, log_results=log_results, debug=debug)

    async def alter_owner(self, full_auth: DomoFullAuth, add_owner_ids_list=None, remove_owner_ids_arr=None,
                          log_results: bool = False, debug: bool = False):

        body = group_routes.generate_body_update_group_membership(group_id=self.group.id,
                                                                  add_owner_user_arr=add_owner_ids_list,
                                                                  remove_owner_user_arr=remove_owner_ids_arr)

        return await self._update_group_access(full_auth=full_auth, body=body, log_results=log_results, debug=debug)

    async def alter_membership(self, full_auth: DomoFullAuth, add_user_ids_list, remove_users_ids_list,
                               log_results: bool = False, debug: bool = False):

        body = group_routes.generate_body_update_group_membership(group_id=self.group.id,
                                                                  add_user_arr=add_user_ids_list,
                                                                  remove_user_arr=remove_users_ids_list)

        return await self._update_group_access(full_auth=full_auth, body=body, log_results=log_results, debug=debug)


class DomoGroups:
    def __init__(self, user):
        self.user = user

    def _groups_to_domo_group(json_list, full_auth: DomoFullAuth):

        return [DomoGroup._from_search_json(full_auth=full_auth, json_obj=json_obj) for json_obj in json_list]

    @classmethod
    async def all_groups(cls, full_auth: DomoFullAuth, debug: bool = False, log_results: bool = False, session: aiohttp.ClientSession = None):

        res = await group_routes.get_all_groups(full_auth=full_auth, debug=debug, log_results=log_results, session=session)

        if res.status != 200:
            return None

        if len(res.response) > 0:
            json_list = res.response

            return cls._groups_to_domo_group(json_list=json_list, full_auth=full_auth)

        else:
            return []


@dataclass
class DomoGroup(Base):
    domo_instance: str = None
    full_auth: DomoFullAuth = None
    id: str = None
    name: str = None
    type: str = None
    description: str = None
    group_members: list = field(repr=False, default_factory=list)
    owner_members: list = field(repr=False, default_factory=list)

    def __post_init__(self):
        self.domo_instance = self.domo_instance or full_auth.domo_instance
        self.Membership = GroupMembership(self)
        Base().__init__()

    @classmethod
    def _from_search_json(cls, full_auth: DomoFullAuth, json_obj):
        dd = DictDot(json_obj)

        g = cls(full_auth=full_auth,
                id=dd.id or dd.groupId,
                domo_instance=full_auth.domo_instance,
                description=dd.description
                )

        g.name = dd.name
        g.type = dd.type or dd.groupType
        g.group_members = dd.groupMembers or dd.users
        g.owner_members = dd.owners
        return g
    
    @classmethod
    def _from_groups_API_json(cls, full_auth: DomoFullAuth, json_obj):
        dd = DictDot(json_obj)

        g = cls(full_auth=full_auth,
                id=dd.id or dd.groupId,
                domo_instance=full_auth.domo_instance,
                description=dd.description
                )

        g.name = dd.name
        g.type = dd.type
        g.group_members = dd.userIds
        return g

    @staticmethod
    def _groups_to_domo_group(json_list, full_auth: DomoFullAuth) -> List[dict]:
        domo_groups = []

        for json_obj in json_list:
            group = DomoGroup._from_search_json(
                full_auth=full_auth,
                json_obj=json_obj)
            domo_groups.append(group)

        return domo_groups

    @classmethod
    async def create_from_name(cls, full_auth: DomoFullAuth,
                               group_name: str = None,
                               group_type: str = None,
                               description: str = None,
                               log_results: bool = False, debug: bool = False):

        res = await group_routes.create_group(full_auth=full_auth,
                                              group_name=group_name,
                                              group_type=group_type,
                                              description=description,
                                              log_results=log_results, debug=debug)

        if log_results:
            res.print(is_pretty=True)

        if res.status == 200 and res.response.get('id'):
            domo_group = cls._from_search_json(
                full_auth=full_auth, json_obj=res.response)
            return domo_group
        
    @classmethod
    async def get_by_id(cls, full_auth:DomoFullAuth,
                        group_id: str):
        res = await group_routes.get_group_by_id(full_auth= full_auth, group_id=group_id)
        if res.status == 200:
            return cls._from_groups_API_json(full_auth = full_auth, json_obj = res.response)

    @classmethod
    async def search_by_name(cls, full_auth: DomoFullAuth,
                             group_name: str,
                             create_if_not_exist: bool = True,
                             allow_only_one: bool = True,
                             debug: bool = False, log_results: bool = False):

        res = await group_routes.search_groups_by_name(full_auth=full_auth, search_name=group_name, debug=debug,
                                                       log_results=log_results)

        if res.status == 200:
            json_list = res.response
            domo_groups = cls._groups_to_domo_group(json_list, full_auth)
            domo_groups = [
                group for group in domo_groups if group.name == group_name]

            if debug:
                print('groups after name filter')
                for group in domo_groups:
                    print(group)

            if create_if_not_exist and not domo_groups:
                if debug:
                    print("create if not exist and not domo groups")
                return await DomoGroup.create_from_name(full_auth=full_auth, group_name=group_name, debug=debug)

            elif allow_only_one:
                if debug:
                    print('allow only one')

                    for group in domo_groups:
                        print(group, group.name, group_name)

                return next((group for group in domo_groups if group.name == group_name), None)

            else:
                return domo_groups
        else:
            return None



import aiohttp
import asyncio

import pandas as pd
import io

import json
from dataclasses import dataclass, field

from .DomoAuth import DomoDeveloperAuth, DomoFullAuth
from .routes import dataflow_routes
from ..utils import Exceptions as ex
from ..utils import convert as cd
from ..utils.Base import Base
from ..utils.DictDot import DictDot


@dataclass
class DomoDataflow(Base):

    id: str
    name: str

    full_auth: DomoFullAuth = field(repr=False, default_factory=list)
    dev_auth: DomoDeveloperAuth = field(repr=False, default_factory=list)

    owner: str = None
    description: str = None
    domo_instance: str = None
    tags: list = None

    @classmethod
    async def get_from_id(cls,
                          id: str,
                          full_auth: DomoFullAuth = None,
                          debug: bool = False, log_results: bool = False):

        try:
            res = await dataflow_routes.get_dataset_by_id(full_auth=full_auth,
                                                          id=id, debug=debug)

            if debug:
                pprint(res)

            # if res.status == 404:
            #     print("f error retrieving get_from_id {full_auth.domo_instance} - {id} status = 404")
            #     raise ex.InvalidDataset(domo_instance=full_auth.domo_instance, dataset_id=id)

            dd = DictDot(res.response)
            ds = cls(
                domo_instance=full_auth.domo_instance or dev_auth.domo_instance,
                full_auth=full_auth,
                id=dd.id,
                name=dd.name,
                description=dd.description,
                owner=dd.owner,
                tags=dd.tags,
            )

            return ds

        except Exception as e:
            print(e)
            return None



import aiohttp
from dataclasses import field, dataclass

from .DomoAuth import DomoFullAuth
from .routes import appdb_routes
from ..utils.Base import Base


@dataclass
class AppdbDocument:
    content: field(default_factory=dict)
    collection_id: str = None
    document_id: str = None

    document_body: field(default_factory=dict) = None

    def __post_init__(self):
        self.generate_doc_body()

    def generate_doc_body(self):
        body = {
            'content': self.content
        }

        self.document_body = body
        return body


@dataclass
class DomoAppDbCollection:
    app_id: str
    domo_environment: str
    collection_name: str
    full_auth: DomoFullAuth

    async def get_documents(self):
        res = await appdb_routes.get_documents(full_auth=self.full_auth,
                                               app_id=self.app_id,
                                               domo_environment=self.domo_environment,
                                               collection_name=self.collection_name)

        if res.status == 200:
            return res.response

    async def create_document(self, content: dict, session: aiohttp.ClientSession = None, debug: bool = False):
        appdb_document = AppdbDocument(content=content)

        res = await appdb_routes.create_document(full_auth=self.full_auth,
                                                 app_id=self.app_id,
                                                 domo_environment=self.domo_environment,
                                                 collection_name=self.collection_name,
                                                 document=appdb_document.document_body,
                                                 session=session,
                                                 debug=debug)
        # if debug:
        print(res)
        if res == 200:
            return res.response
